#!/usr/bin/perl

# Use with LaTeX2HTML v2008
package main;

&do_require_package("report");
&do_require_package("makeidx");
&do_require_package("alltt");
&do_require_package("amsmath");
&do_require_package("color");
&do_require_package("html");
&do_require_package("datetime");

&do_require_package('inputenc');
&do_inputenc_utf8;

$STYLESHEET = '';
$STYLESHEET_CASCADE = <<_END_CSS;
<style type="text/css">
div#sidebar div.level
{
  display: none;
}
div#sidebar span.level
{
  display: inline;
  position: absolute;
  left: 0em;
}
div.TofC
{
  margin-left: 1em;
}
div.TofC dl span.level
{
  display: inline;
  width: 1em;
  position:absolute;
  margin-left: -1.25em;
  text-align: center;
  font-size: small;
}
div#sidebar ul li
{
  list-style: none;
  line-height: 1.5em;
  padding-left: 0.125em;
  margin-left: 0em;
}
span.basic
{
  color: green;
}
span.medium
{
  color: orange;
}
span.hard
{
  color: red;
}
ul.LoF li, ul.LoT li {list-style-type: none;}

</style>
<!--#include virtual="/navigation/styles.html" -->
_END_CSS

@LEVELINFO = 
 (
   {label=>'basic', symbol=>'&#x204E;', description=>'Basic Level'},
   {label=>'medium', symbol=>'&#x2051;', description=>'Intermediate Level'},
   {label=>'hard', symbol=>'&#x2042;', description=>'Advanced Level'},
 );

@IMAGE_PATH = ();

sub do_admin_html{}

%section_commands = 
(
  'listofexamples', '2',
  'listofexercises', '2',
  'backcoverheading', '2',
   %section_commands
);

&do_require_package("glossaries");

&make_newglossarytype("acronym", "\\acronymname");
$acronymtype = 'acronym';

$gls_title{'main'} = "Summary";
$gls_toctitle{'main'} = "Summary";

$SUMMARYTYPE='main';

$sidepanelcontents = '';

$INDEXONLYFIRST=1;

$LISTOFEXAMPLESTITLE = 'List of Examples';
$LISTOFEXERCISESTITLE = 'List of Exercises';
$BACKCOVERTITLE = 'Back Cover Text';

$use_description_list = 1;
$SHOW_SECTION_NUMBERS = 1;

# Helps with the sort if symbols are indexed as the HTML numeric
# entities

sub unicode_entity{
   sprintf "&#x%0.4X;", ord($_[0]);
}

sub do_cmd_frontmatter{
  $SHOW_SECTION_NUMBERS=0;

  @_[0];
}

sub do_cmd_mainmatter{

  $SHOW_SECTION_NUMBERS=1;

  $global{chapter} = 0;

  @_[0];
}

sub do_cmd_backmatter{
  $SHOW_SECTION_NUMBERS=0;

  @_[0];
}

sub do_cmd_listofexamples{
  local($after,$ot) = @_;

  local($id) = ++$global{'max_id'};

  $after = "$O$id$C$LISTOFEXAMPLESTITLE$O$id$C\\deferredlistofexamples $after";

  local($open_tags_R) = defined $ot ? $ot : $open_tags_R;

  &do_cmd_section_helper('H1', 'chapterstar');
}

sub do_cmd_listofexercises{
  local($after,$ot) = @_;

  local($id) = ++$global{'max_id'};

  $after = "$O$id$C$LISTOFEXERCISESTITLE$O$id$C\\deferredlistofexercises $after";

  local($open_tags_R) = defined $ot ? $ot : $open_tags_R;

  &do_cmd_section_helper('H1', 'chapterstar');
}

sub do_cmd_backcoverheading{
  local($after,$ot) = @_;

  local($id) = ++$global{'max_id'};

  $after = "$O$id$C$BACKCOVERTITLE$O$id$C $after";

  local($open_tags_R) = defined $ot ? $ot : $open_tags_R;

  &do_cmd_section_helper('H1', 'chapterstar');
}

$ADDRESS = '';

$MAX_LINK_DEPTH=1;
$child_name='';
$NUMBERED_FOOTNOTES=1;
$TOP_NAVIGATION=1;
$BOTTOM_NAVIGATION=1;
$WORDS_IN_NAVIGATION_PANEL_TITLES=7;

$CHILDLINE = "<BR>";
sub upper_child_line{ '<BR>'; };

$UPCHAR = '<DIV CLASS="navigiatesym">&#x21E7;</DIV>';
$PREVCHAR = '<DIV CLASS="navigatesym">&#x21E6;</DIV>';
$NEXTCHAR = '<DIV CLASS="navigatesym">&#x21E8;</DIV>';

sub top_navigation_panel{
  local($gonext) = $NEXT;
  local($goprev) = $PREVIOUS;
  local($goup) = $UP;

  $USING_STYLES=0;

  if ($gonext=~s/<tex2html_next_page_visible_mark>/$NEXTCHAR Next/)
  {
     my $next_title = $NEXT_TITLE;

     $next_title=~s|<A[^>]*>(.*)</A>|$1|;

     $next_title=~s/"//g;

     $gonext = "<DIV CLASS=\"navigatenext\" TITLE=\"$next_title\">$gonext</DIV>";
  }
  else
  {
    $gonext=~s/<tex2html_next_page_inactive_visible_mark>/<DIV CLASS="disnavigatenext">$NEXTCHAR Next<\/DIV>/;
  }

  if ($goprev=~s/<tex2html_previous_page_visible_mark>/$PREVCHAR Previous/)
  {
     my $prev_title = $PREVIOUS_TITLE;

     $prev_title=~s|<A[^>]*>(.*)</A>|$1|;

     $prev_title=~s/"//g;

     $goprev = "<DIV CLASS=\"navigateprev\" TITLE=\"$prev_title\">$goprev</DIV>";
  }
  else
  {
    $goprev=~s/<tex2html_previous_page_inactive_visible_mark>/<DIV CLASS="disnavigateprev">$PREVCHAR Previous<\/DIV>/;
  }

  if ($goup=~s/<tex2html_up_visible_mark>/$UPCHAR Up/)
  {
     my $up_title = $UP_TITLE;

     $up_title=~s|<A[^>]*>(.*)</A>|$1|;

     $up_title=~s/"//g;

     $goup = "<DIV CLASS=\"navigateup\" TITLE=\"$up_title\">$goup</DIV>";
  }
  else
  {
    $goup=~s/<tex2html_up_inactive_visible_mark>/<DIV CLASS="disnavigateup">$UPCHAR Up<\/DIV>/;
  }

  $MAX_LINK_DEPTH=1;
  local ($nav) = &add_child_links('', $file, $depth, $child_star, $key, @keys);
  $MAX_LINK_DEPTH=-1;

<<_END_HEADER_TEXT;
    <!--#include virtual="/navigation/headerh.shtml" -->
    <DIV ID="sidebar"><!--#include virtual="/navigation/sidebarheader.shtml" -->
     <DIV STYLE="text-align: center;">
     <A HREF="../index.shtml">&#x2302; $t_title</A><P>
     <A HREF="contents$EXTN">Contents</A>
     <A HREF="summary$EXTN">Summary</A>
     <A HREF="bookindex$EXTN">Index</A>
     </div>
    <P>
    <DIV CLASS="navigate">
    $goprev $goup $gonext
    <BR>
    </DIV>
    <P>
    $nav
    <DIV CLASS="idxnav"></DIV>
    </div>
    <DIV ID="main">
_END_HEADER_TEXT
}

sub bot_navigation_panel{
  local($gonext) = $NEXT;
  local($goprev) = $PREVIOUS;
  local($goup) = $UP;

  if ($gonext=~s/<tex2html_next_page_visible_mark>/$NEXTCHAR/)
  {
     my $next_title = $NEXT_TITLE;

     $next_title=~s|<A[^>]*>(.*)</A>|$1|;

     $next_title=~s/"//g;

     $gonext = "<DIV CLASS=\"bottomnavigatenext\" TITLE=\"$next_title\">$gonext</DIV>";
  }
  else
  {
    $gonext=~s/<tex2html_next_page_inactive_visible_mark>/<DIV CLASS="bottomdisnavigatenext">$NEXTCHAR<\/DIV>/;
  }

  if ($goprev=~s/<tex2html_previous_page_visible_mark>/$PREVCHAR/)
  {
     my $prev_title = $PREVIOUS_TITLE;

     $prev_title=~s|<A[^>]*>(.*)</A>|$1|;

     $prev_title=~s/"//g;

     $goprev = "<DIV CLASS=\"bottomnavigateprev\" TITLE=\"$prev_title\">$goprev</DIV>";
  }
  else
  {
    $goprev=~s/<tex2html_previous_page_inactive_visible_mark>/<DIV CLASS="bottomdisnavigateprev">$PREVCHAR<\/DIV>/;
  }

  if ($goup=~s/<tex2html_up_visible_mark>/$UPCHAR/)
  {
     my $up_title = $UP_TITLE;

     $up_title=~s|<A[^>]*>(.*)</A>|$1|;

     $up_title=~s/"//g;

     $goup = "<DIV CLASS=\"bottomnavigateup\" TITLE=\"$up_title\">$goup</DIV>";
  }
  else
  {
    $goup=~s/<tex2html_up_inactive_visible_mark>/<DIV CLASS="bottomdisnavigateup">$UPCHAR<\/DIV>/;
  }

<<"_END_TEXT";
      $goprev
      $goup
      $gonext
    <HR>
    This book is also available as <A HREF="../admin-report.pdf">A4 PDF</A> or <A HREF="../admin-screen.pdf">12.8cm x 9.6cm PDF</A> or <A HREF="${t_homepage}shop/product_info.php?cPath=23_25&amp;products_id=36">paperback (ISBN 978-1-909440-07-4)</A>.
     <!--#set var="CopyYear" value="2015" -->
     <!--#include virtual="/navigation/footer.shtml" -->
    </DIV>
_END_TEXT
}

# modify some of latex2html's subroutines
eval(<<'_END_EVAL');
sub replace_markers {
    &find_quote_ligatures;
    &replace_general_markers;
    &replace_extra_markers;
    &text_cleanup;
    &replace_sensitive_markers;
    &replace_init_file_mark if (/$init_file_mark/);
    &replace_file_marks;
    &post_replace_markers;
}

sub make_named_href {
    local($name, $link, $text) = @_;
    $text =~ s/<A .*><\/A>//go;
    $text = &simplify($text);
    if ($text eq $link) { $text =~ s/~/&#126;/g; }
    $link =~ s/~/&#126;/g;
    $link =~ s/\\(html)?url\s*(($O|$OP)\d+($C|$CP))([^<]*)\2/$5/;
    $link =~ s:(<TT>)?<A [^>]*>([^<]*)</A>(</TT>)?(([^<]*)|$):$2$4:;

    my $target = '';

    if ($link=~m|^https?://| and not $link=~/^$t_homepage/)
    {
       $target = 'TARGET="_blank"';
    }

    if (!($name)) {"<A $target\n HREF=\"$link\">$text</A>";}
    elsif ($text =~ /^\w/) {"<A $target NAME=\"$name\"\n HREF=\"$link\">$text</A>";}
    else {"<A $target NAME=\"$name\"\n HREF=\"$link\">$text</A>";}
}

sub make_real_href {
    local($link, $text) = @_;
    $href_name++;

    my $htarget = '';

    $text =~ s/<A .*><\/A>//go;
    if ($text eq $link) { $text =~ s/~/&#126;/g; }
    $link =~ s/~/&#126;/g;
    $link =~ s/\\(html)?url\s*(($O|$OP)\d+($C|$CP))([^<]*)\2/$5/;
    $link =~ s:(<TT>)?<A [^>]*>([^<]*)</A>(</TT>)?(([^<]*)|$):$2$4:;
    $text = &simplify($text);

    if ($target)
    {
      $htarget = ' TARGET="'.$target.'"';
    }
    else
    {
       if ($link=~m|^https?://| and not $link=~/^$t_homepage/)
       {
          $htarget = ' TARGET="_blank"';
       }
    }

    "<A NAME=\"tex2html$href_name\"$htarget\n  HREF=\"$link\">$text</A>";
}


sub add_idx{
   local($sidx_style, $eidx_style) =("","");
   &add_book_idx(@_);
}

sub named_index_entry{
   &book_named_index_entry(@_);
}

sub do_env_alltt {
    local ($_) = @_;
    local($closures,$reopens,$alltt_start,$alltt_end,@open_block_tags);

    $alltt_start = "\n<DIV CLASS=\"alltt\" ALIGN=\"LEFT\">\n";
    $alltt_end = "\n</DIV>\n";

    # get the tag-strings for all open tags
    local(@keep_open_tags) = @$open_tags_R;
    ($closures,$reopens) = &preserve_open_tags() if (@$open_tags_R);

    # get the tags for text-level tags only
    $open_tags_R = [ @keep_open_tags ];
    local($local_closures, $local_reopens);
    ($local_closures, $local_reopens,@open_block_tags) = &preserve_open_block_tags
	if (@$open_tags_R);

    $open_tags_R = [ @open_block_tags ];

    do {
	local($open_tags_R) = [ @open_block_tags ];
	local(@save_open_tags) = ();

	local($cnt) = ++$global{'max_id'};
	$_ = join('',"$O$cnt$C\\tt$O", ++$global{'max_id'}, $C
		, $_ , $O, $global{'max_id'}, "$C$O$cnt$C");

	$_ = &translate_environments($_);
	$_ = &translate_commands($_) if (/\\/);

	# preserve space-runs, using &nbsp;
	while (s/(\S) ( +)/$1$2;SPMnbsp;/g){};
	s/(<BR>) /$1;SPMnbsp;/g;

	$_ = join('', $closures, $alltt_start , $local_reopens
		, $_
		, &balance_tags() #, $local_closures
		, $alltt_end, $reopens);
	undef $open_tags_R; undef @save_open_tags;
    };

    $open_tags_R = [ @keep_open_tags ];
    $_;
}

sub add_toc_hook{
  local(@keys) = keys %toc_section_info;

  foreach my $key (@keys)
  {
     for (my $idx = 0; $idx <= $#LEVELINFO; $idx++)
     {
        last if $toc_section_info{$key}=~s/%([\d\.]* )($LEVELINFO[$idx]{'symbol'})/%<SPAN CLASS="level"><SPAN CLASS="$LEVELINFO[$idx]{'label'}">$2<\/SPAN><\/SPAN>$1/;
     }
  }

  my $symbols = '<P>Symbols: ';

  for (my $idx = 0; $idx <= $#LEVELINFO; $idx++)
  {
     $symbols .= " <SPAN CLASS=\"$LEVELINFO[$idx]{'label'}\">$LEVELINFO[$idx]{'symbol'}</SPAN> $LEVELINFO[$idx]{'description'}";
  }

  $symbols .= '.';

  s/$toc_mark/<DIV CLASS="TofC">$symbols$toc_mark<\/DIV>/;

  &add_toc(@_);
}

sub do_cmd_listoffigures {
    local($_) = @_;
    local($list_type) = 'UL';
    if ((defined &do_cmd_listfigurename)||$new_command{'listfigurename'}) {
	local($br_id)=++$global{'max_id'};
	$TITLE = &translate_environments("$O$br_id$C\\listfigurename$O$br_id$C");
    } else { $TITLE = $lof_title }
    $toc_sec_title = $TITLE;
    $loffile = $CURRENT_FILE;  # sets  $loffile  this globally
    local $lof_head = $section_headings{'listoffigures'};
    local($closures,$reopens) = &preserve_open_tags();
    join('', "<BR>\n", $closures
	 , &make_section_heading($TITLE, $lof_head)
	 , "<$list_type CLASS=\"LoF\">", $lof_mark, "</$list_type>"
	 , $reopens, $_);
}
sub do_cmd_listoftables {
    local($_) = @_;
    local($list_type) = 'UL';
    if ((defined &do_cmd_listtablename)||$new_command{'listtablename'}) {
	local($br_id)=++$global{'max_id'};
	$TITLE = &translate_environments("$O$br_id$C\\listtablename$O$br_id$C");
    } else { $TITLE = $lot_title }
    $toc_sec_title = $TITLE;
    $lotfile = $CURRENT_FILE;  # sets  $lotfile  this globally
    local $lot_head = $section_headings{'listoftables'};
    local($closures,$reopens) = &preserve_open_tags();
    join('', "<BR>\n", $closures
	 , &make_section_heading($TITLE, $lot_head)
	 , "<$list_type CLASS=\"LoT\">", $lot_mark, "</$list_type>"
	 , $reopens, $_);
}

_END_EVAL

sub replace_extra_markers{
  s/<DIV CLASS="idxnav"><\/DIV>/$sidepanelcontents/m;
  $sidepanelcontents = '';
}

$global{'example'} = 0;

sub do_cmd_theexample{
   local($_) = @_;

   $global{'example'}.$_;
}

$global{'exercise'} = 0;

sub do_cmd_theexercise{
   local($_) = @_;

   $global{'exercise'}.$_;
}

sub do_env_fwlist{
   local($_) = @_;
   local($maxtag);

   $maxtag = &missing_braces
              unless (s/$next_pair_rx/$maxtag=$2,''/eo);

  "<DL>$_</DL>";
}

sub do_cmd_fwitem{
   local($_) = @_;
   local($text);

   $text = &missing_braces
              unless (s/$next_pair_pr_rx/$text=$2,''/eo);

   "<DT>$text</DT><DD>".$_;
}

sub do_env_example{
   local($_) = @_;
   local($title, $label,$id1, $id2);

   local($backref,$pat) = &get_next_optional_argument;

   $title = &missing_braces
              unless (s/$next_pair_rx/$id1=$1,$title=$2,''/eo);

   $label = &missing_braces
              unless (s/$next_pair_rx/$id2=$1,$label=$2,''/eo);

   &translate_commands(
      "\\refstepcounter$OP$id1${CP}example$OP$id1$CP"
     ."\\label$OP$id2$CP$label$OP$id2$CP").

   "<DIV CLASS=\"example\"><B>Example $global{example}. $title</B><P>" . $_ . "</DIV>";
}

sub do_cmd_deferredlistofexamples{
   local($_) = @_;

   local($ext) = "hloe";

   local($after) = $_;

   unless (&process_ext_file($ext))
   {
      &write_warnings("\nThe '$FILE.$ext' was not found.");
   }

   $_.$after;
}

sub do_env_examplelist{
  local($_) = @_;

  "<OL>$_</OL>\n<P>\n<A HREF=\"examples/index.shtml\">Download Example Files</A>";
}

sub do_cmd_htmlexampleitem{
   local($_) = @_;

   local($id, $title, $label, $node, $num);

   $title = &missing_braces
              unless (s/$next_pair_pr_rx/$id1=$1,$title=$2,''/eo);

   $label = &missing_braces
              unless (s/$next_pair_pr_rx/$id2=$1,$label=$2,''/eo);

   $node = &missing_braces
              unless (s/$next_pair_pr_rx/$id2=$1,$node=$2,''/eo);

   $num = &missing_braces
              unless (s/$next_pair_pr_rx/$id2=$1,$num=$2,''/eo);

   "<LI VALUE=\"$num\"> <A HREF=\"$node$EXTN#$label\">$title</A>$_";
}

sub do_env_exercise{
   local($_) = @_;
   local($title, $label,$id1, $id2);

   local($backref,$pat) = &get_next_optional_argument;

   $title = &missing_braces
              unless (s/$next_pair_rx/$id1=$1,$title=$2,''/eo);

   $label = &missing_braces
              unless (s/$next_pair_rx/$id2=$1,$label=$2,''/eo);

   &translate_commands(
      "\\refstepcounter$OP$id1${CP}exercise$OP$id1$CP"
     ."\\label$OP$id2$CP$label$OP$id2$CP").

   "<DIV CLASS=\"exercise\"><B>Exercise $global{exercise}. $title</B><P>" . $_ . "</DIV>";
}

sub do_cmd_deferredlistofexercises{
   local($_) = @_;

   local($ext) = "hlox";

   local($after) = $_;

   unless (&process_ext_file($ext))
   {
      &write_warnings("\nThe '$FILE.$ext' was not found.");
   }

   $_.$after;
}

sub do_env_exerciselist{
  local($_) = @_;

  "<OL>$_</OL>\n<P>\n<A HREF=\"exercises/index.shtml\">Download Exercise Files</A>";
}

sub do_cmd_htmlexerciseitem{
   local($_) = @_;

   local($id, $title, $label, $node, $num);

   $title = &missing_braces
              unless (s/$next_pair_pr_rx/$id1=$1,$title=$2,''/eo);

   $label = &missing_braces
              unless (s/$next_pair_pr_rx/$id2=$1,$label=$2,''/eo);

   $node = &missing_braces
              unless (s/$next_pair_pr_rx/$id2=$1,$node=$2,''/eo);

   $num = &missing_braces
              unless (s/$next_pair_pr_rx/$id2=$1,$num=$2,''/eo);

   "<LI VALUE=\"$num\"> <A HREF=\"$node$EXTN#$label\">$title</A>$_";
}

$EXTRA_IMAGE_SCALE=2;

sub do_env_htmlresult{
   local($_) = @_;
   local($desc, $id);

   $desc = &missing_braces
              unless (s/$next_pair_rx/$id=$1,$desc=$2,''/eo);

   local ($id2) = ++$global{'max_id'};

   local($code) = $_;

   unless ($desc)
   {
     $desc = "Image showing typeset output";
   }

   $desc=~s/\\n/ /g;

   $desc=~s/\\tildesym /~/g;

   unless ($desc)
   {
      &write_warnings("No alternative text provided for htmlresult ($code)");
   }

   $code=~s/\\begin$O(\d+)${C}makeimage$O\1$C/$&\\htmlimage$O$id${C}alt=$desc$O$id$C$O$id2$C$O$id2$C/;

   &make_result_block($code)
}

sub make_result_block{
  "<DIV CLASS=\"result\" TITLE=\"result\">$_[0]</DIV><P>";
}

# don't convert contents of starred form into an image
sub do_env_resultSstar{
   local($_) = @_;

   local ($contents) = &translate_commands($_);

   &make_result_block($contents);
}

sub do_env_code{
   local($_) = @_;
   local($width,$pat) = &get_next_optional_argument;

   # Each \gls adds <CODE></CODE> which is unnecessary
   # inside this environment.

   local($code) = &translate_commands($_);
   $code=~s/<\/?CODE>//g;

   "<P><DIV CLASS=\"code\" TITLE=\"input\"><PRE>$code</PRE></DIV><P>";
}

sub do_env_codeS{
   local($_) = @_;
   local($width,$pat) = &get_next_optional_argument;

   local($code) = &translate_commands($_);
   $code=~s/<\/?CODE>//g;

   "<P><DIV CLASS=\"code\" TITLE=\"input\"><CODE>$code</CODE></DIV><P>";
}

sub do_cmd_hidden{
   local($_) = @_;

   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;
   "<SPAN STYLE=\"display: none;\">$text</SPAN>$_"
}

sub do_cmd_shellnewline{
   local($_) = @_;

   # trim any leading space
   s/^\s*//;

   "<BR><SPAN CLASS=\"prompt\" TITLE=\"shell prompt\">\$&nbsp;</SPAN>$_";
}

sub do_env_shell{
   local($_) = @_;
   local($width,$pat) = &get_next_optional_argument;
   "<P><DIV CLASS=\"shell\" TITLE=\"shell command\"><SPAN CLASS=\"prompt\" TITLE=\"shell prompt\">\$&nbsp;</SPAN><KBD>$_</KBD></DIV><P>";
}

sub do_env_SQLshell{
   local($_) = @_;
   local($width,$pat) = &get_next_optional_argument;
   "<P><DIV CLASS=\"shell\" TITLE=\"SQL command\"><SPAN CLASS=\"prompt\" TITLE=\"SQL prompt\">&gt;&nbsp;</SPAN><KBD>$_</KBD></DIV><P>";
}

sub do_env_definition{
   local($_) = @_;
   local($width,$pat) = &get_next_optional_argument;
   local($defn) = &translate_commands($_);
   $defn=~s/<\/?CODE>//g;

   "<P><DIV CLASS=\"definition\" TITLE=\"definition\">$defn</DIV><P>";
}

sub do_env_display{
   local($_) = @_;
   local($width,$pat) = &get_next_optional_argument;
   s/\n/\n<BR>/g;
   "<P><DIV CLASS=\"displayblock\">$_</DIV><P>";
}

sub do_cmd_keywords{
   local($_) = @_;
   local($keywords);

   $keywords = &missing_braces unless
      s/$next_pair_pr_rx/$keywords=$2;''/eo;

   "<META NAME=\"Keywords\" CONTEXT=\"$keywords\">".$_;
}

sub do_cmd_ifstrempty{
   local($_) = @_;
   local($text, $truepart, $falsepart);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   $truepart = &missing_braces unless
      s/$next_pair_pr_rx/$truepart=$2;''/eo;

   $falsepart = &missing_braces unless
      s/$next_pair_pr_rx/$falsepart=$2;''/eo;

   join('', ($text=~/^$/ ? $truepart : $falsepart), $_)
}

sub do_cmd_optfmt{
   local($_) = @_;
   local($opt);

   $opt = &missing_braces unless
      s/$next_pair_pr_rx/$opt=$2;''/eo;

   "<CODE>$opt</CODE>".$_;
}

sub do_cmd_nolinkurl{
   local($_) = @_;
   local($topic);

   $url = &missing_braces unless
      s/$next_pair_pr_rx/$url=$2;''/eo;

   $url =~ s/\\?~/;SPMtilde;/og;

   "<TT>$url</TT>".$_;
}

sub do_cmd_mirror{
   local($_) = @_;
   local($ref);

   $ref = &missing_braces unless
      s/$next_pair_pr_rx/$ref=$2;''/eo;

   local $suffix = '';

   if ($ref=~/\.pdf$/)
   {
      $suffix = ' (PDF)';
   }
   elsif ($ref=~/README/)
   {
      $suffix = ' (README)';
   }

   "<A TARGET=\"_blank\" HREF=\"http://mirrors.ctan.org/$ref\">CTAN Mirror$suffix</A>".$_;
}

sub do_cmd_ctopicfmt{
   local($_) = @_;
   local($topic);

   $topic = &missing_braces unless
      s/$next_pair_pr_rx/$topic=$2;''/eo;

   $topic.$_;
}

sub do_topiclink{
   local($label, $text) = @_;

   "<A TARGET=\"_blank\" HREF=\"http://ctan.org/topic/$label\">$text</A>"
}

sub do_cmd_ctopicstar{
   local($_) = @_;
   local($label,$id);

   $label = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   &do_topiclink($label, "\\ctopicfmt$OP$id${CP}$label$OP$id${CP}").$_;
}

sub do_cmd_ctopic{
   local($_) = @_;
   local($label,$id);

   local($text,$pat) = &get_next_optional_argument;

   $label = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   unless ($text)
   {
      $text = "\\ctopicfmt$OP$id${CP}$label$OP$id${CP} topic";
   }

   &do_topiclink($label, $text).$_;
}

sub do_cmd_catalogue{
   local($_) = @_;
   local($title, $label);

   $title = &missing_braces unless
      s/$next_pair_pr_rx/$title=$2;''/eo;

   $label = &missing_braces unless
      s/$next_pair_pr_rx/$label=$2;''/eo;

   join('', "<A TARGET=\"_blank\" HREF=\"http://mirror.ctan.org/help/Catalogue/bytopic.html#$label\">&#x201C;", 
        $title,
        "&#x201D; section</A>",
        $_);
}

sub do_faqlink{
   local($title, $label) = @_;

   "<A TARGET=\"_blank\" HREF=\"http://www.tex.ac.uk/cgi-bin/texfaq2html?label=$label\">$title</A>"
}

sub do_cmd_faqlink{
   local($_) = @_;
   local($title,$label);

   $title = &missing_braces unless
      s/$next_pair_pr_rx/$title=$2;''/eo;

   $label = &missing_braces unless
      s/$next_pair_pr_rx/$label=$2;''/eo;

   &do_faqlink($title, $label).$_;
}

sub do_cmd_faq{
   local($_) = @_;
   local($title,$label);

   $title = &missing_braces unless
      s/$next_pair_pr_rx/$id1=$1,$title=$2;''/eo;

   $label = &missing_braces unless
      s/$next_pair_pr_rx/$id2=$1,$label=$2;''/eo;

   " <CITE>[".&do_faqlink($title,$label)."]</CITE> ".$_;
}

sub do_cmd_meta{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   &do_meta($text) . $_;
}

sub do_cmd_dmeta{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   &do_meta($text) . $_;
}

sub do_meta{
  local($text) = @_;
   "&#x27E8;<VAR TITLE=\"Metasyntactic variable\">$text</VAR>&#x27E9;";
}

sub do_cmd_file{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   $text=~s/~/&unicode_entity('~')/eog;

   "<TT>$text</TT>$_";
}

sub do_cmd_dq{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "&#x201C;$text&#x201D;" . $_;
}

sub do_cmd_sq{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "&#x2018;$text&#x2019;" . $_;
}

sub do_cmd_upsq{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "'$text'" . $_;
}

sub do_cmd_updq{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "\"$text\"" . $_;
}

sub do_cmd_hyperpage{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   $text . $_;
}

sub do_cmd_indexdef{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<EM>$text</EM>" . $_;
}

sub do_cmd_indexglo{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<B>$text</B>" . $_;
}

sub do_cmd_ttbackslash{
   local($_) = @_;

   '<TT>'.&unicode_entity('\\').'</TT>' . $_;
}

sub do_cmd_marg{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE><A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:leftbracechar\">{</A>"
    .$text
    ."<A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:rightbracechar\">}</A></CODE>" . $_;
}

sub do_cmd_margstar{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>{$text}</CODE>" . $_;
}

sub do_cmd_margm{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE><A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:leftbracechar\">{</A></CODE>"
    .&do_meta($text)
    ."<CODE><A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:rightbracechar\">}</A></CODE>" . $_;
}

sub do_cmd_margmstar{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>{</CODE>".&do_meta($text)."<CODE>}</CODE>" . $_;
}

sub do_cmd_oarg{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE><A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:opt.opensq\">[</A>"
    .$text
    ."<A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:opt.closesq\">]</A></CODE>" . $_;
}

sub do_cmd_oargstar{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>[$text]</CODE>" . $_;
}

sub do_cmd_oargm{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE><A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:opt.opensq\">[</A></CODE>"
    .&do_meta($text)
    ."<CODE><A CLASS=\"gls\" HREF=\"$gls_file_mark{main}#gls:opt.closesq\">]</A></CODE>" . $_;
}

sub do_cmd_oargmstar{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>[".&do_meta($text)."]</CODE>" . $_;
}

sub do_cmd_parg{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>($text)</CODE>" . $_;
}

sub do_cmd_pargm{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>(".&do_meta($text).")</CODE>" . $_;
}

sub do_cmd_mname{
   local($_) = @_;

   &do_meta('name') . $_;
}

# use HTML unicode hex entities for symbols to prevent them from
# being interpreted and to assist indexing.

sub do_cmd_leftbrace{
   local($_) = @_;
   &unicode_entity('{').$_;
}

sub do_cmd_rightbrace{
   local($_) = @_;
   &unicode_entity('}').$_;
}

sub do_cmd_leftbracesym{
   local($_) = @_;
   &unicode_entity('{').$_;
}

sub do_cmd_rightbracesym{
   local($_) = @_;
   &unicode_entity('}').$_;
}

sub do_cmd_leftsqbrace{
   local($_) = @_;
   &unicode_entity('[').$_;
}

sub do_cmd_rightsqbrace{
   local($_) = @_;
   &unicode_entity(']').$_;
}

sub do_cmd_percentsym{
   local($_) = @_;
   &unicode_entity('%').$_;
}

sub do_cmd_hashsym{
   local($_) = @_;
   &unicode_entity('#').$_;
}

sub do_cmd_dbhashsym{
   local($_) = @_;
   &unicode_entity('#').&unicode_entity('#').$_;
}

sub do_cmd_atsym{
   local($_) = @_;
   &unicode_entity('@').$_;
}

sub do_cmd_xatsym{
   local($_) = @_;
   &unicode_entity('@').$_;
}

sub do_cmd_actualchar{
   local($_) = @_;
   '@'.$_;
}

sub do_cmd_ampsym{
   local($_) = @_;
   &unicode_entity('&').$_;
}

sub do_cmd_vbarsym{
   local($_) = @_;
   &unicode_entity('|').$_;
}

sub do_cmd_questionsym{
   local($_) = @_;
   &unicode_entity('?').$_;
}

sub do_cmd_dollarsym{
   local($_) = @_;
   &unicode_entity('$').$_;
}

sub do_cmd_tabsym{
   local($_) = @_;
   "&#x21B9;".$_;
}

sub do_cmd_itabsym{
   local($_)=@_;

   local($id) = ++$global{'max_id'};

   "&#x21B9;\\index$OP$id${CP}tab character\@tab character &#x21B9;$OP$id$CP".$_;
}

sub do_cmd_entersym{
   local($_) = @_;
   "&#x23CE;".$_;
}

sub do_cmd_Square{
   local($_) = @_;
   "&#x2610;".$_;
}

sub do_cmd_CheckedBox{
   local($_) = @_;
   "&#x2611;".$_;
}

sub do_cmd_XBox{
   local($_) = @_;
   "&#x2612;".$_;
}

sub do_cmd_ecircumacute{
   local($_) = @_;
   "&#x1EBF;".$_;
}

sub do_cmd_keyword{
   local($_) = @_;
   local($text,$indextext,$pat,$id);

   ($indextext,$pat) = &get_next_optional_argument;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   if ($indextext eq '')
   {
      $indextext = $text
   }

   &translate_commands("\\keywordfmt $OP$id$CP$text$OP$id$CP")
    . "\\index$OP$id$CP$indextext$OP$id$CP" . $_;
}

sub do_cmd_symbolcmddef{
   local($_) = @_;
   local($symbol,$id);

   $symbol = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$symbol=$2;''/eo;

  '<CODE>'.&unicode_entity('\\')."$symbol</CODE>\\indexsymbolcmddef$OP$id$CP$symbol$OP$id$CP".$_;
}

sub do_cmd_indexsymbolcmddef{
   local($_) = @_;
   local($symbol,$id);

   $symbol = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$symbol=$2;''/eo;

  "\\index$OP$id$CP".&unicode_entity('\\')
   . "$symbol@<CODE>".&unicode_entity('\\')
   . "$symbol</CODE>|indexdef$OP$id$CP".$_;
}

sub do_cmd_symbolcmd{
   local($_) = @_;
   local($symbol,$id);

   $symbol = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$symbol=$2;''/eo;

  '<CODE>'
  . &unicode_entity('\\')
  ."$symbol</CODE>\\indexsymbolcmd$OP$id$CP$symbol$OP$id$CP".$_;
}

sub do_cmd_indexsymbolcmd{
   local($_) = @_;
   local($symbol,$id);

   $symbol = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$symbol=$2;''/eo;

  "\\index$OP$id$CP"
   . &unicode_entity('\\')
   . "$symbol@<CODE>"
   . &unicode_entity('\\')
   . "$symbol</CODE>$OP$id$CP".$_;
}

sub do_cmd_ibackslashcircumdef{
   local($_)=@_;

   local($id) = ++$global{'max_id'};

   local($text) = &unicode_entity('\\').&unicode_entity('^');

   "<CODE>$text</CODE>\\index$OP$id$CP$text@<CODE>$text</CODE>$OP$id$CP".$_;
}

sub do_cmd_backslashcircumsort{
   local($_)=@_;

   &unicode_entity('\\').&unicode_entity('^') . $_;
}

sub do_cmd_ibackslashtildedef{
   local($_)=@_;

   local($id) = ++$global{'max_id'};

   local($text) = &unicode_entity('\\').&unicode_entity('~');

   "<CODE>$text</CODE>\\index$OP$id$CP$text@<CODE>$text</CODE>$OP$id$CP".$_;
}

sub do_cmd_backslashtildesort{
   local($_)=@_;

   &unicode_entity('\\').&unicode_entity('~'). $_;
}

sub do_cmd_idblquote{
   local($_)=@_;

   local($id) = ++$global{'max_id'};

   local($text) = &unicode_entity('"');

   "<CODE>$text</CODE>\\index$OP$id$CP$text@<CODE>$text</CODE>$OP$id$CP".$_;
}

sub indexfileformat{
   local($ext) = @_;

   local($id) = ++$global{'max_id'};

   &named_index_entry($id, "file formats!.$ext@<CODE>.$ext</CODE>"),
}

sub do_cmd_indexEPS{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "Encapsulated PostScript (EPS) file"),
      &indexfileformat('eps'),
      $_);
}

sub do_cmd_indexPDF{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "Portable Document Format (PDF) file"),
      &indexfileformat('pdf'),
      $_);
}

sub do_cmd_indexDVI{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "Device Independent (DVI) file"),
      &indexfileformat('dvi'),
      $_);
}

sub do_cmd_indexSYNCTEX{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "synctex file"),
      &indexfileformat('synctex.gz'),
      $_);
}

sub do_cmd_indexCLS{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "class files"),
      &indexfileformat('cls'),
      $_);
}

sub do_cmd_indexSTY{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "package files"),
      &indexfileformat('sty'),
      $_);
}

sub do_cmd_indexTOC{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "table of contents (toc) file"),
      &indexfileformat('toc'),
      $_);
}

sub do_cmd_indexLOF{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "list of figures (lof) file"),
      &indexfileformat('lof'),
      $_);
}

sub do_cmd_indexLOT{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "list of tables (lot) file"),
      &indexfileformat('lot'),
      $_);
}

sub do_cmd_indexLOG{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "log file"),
      &indexfileformat('log'),
      $_);
}

sub do_cmd_indexAUX{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "auxiliary file"),
      &indexfileformat('aux'),
      $_);
}

sub do_cmd_iauxfile{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('', 
      'auxiliary (<TT>.aux</TT>) file',
      &named_index_entry($id, "auxiliary file"),
      &indexfileformat('aux'),
      $_);
}

sub do_cmd_indexSOC{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "list or summary of changes (soc) file"),
      &indexfileformat('soc'),
      $_);
}

sub do_cmd_isocfile{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('', 
      '<TT>.soc</TT>',
      &named_index_entry($id, "list or summary of changes (soc) file"),
      &indexfileformat('soc'),
      $_);
}

sub do_cmd_indexDBTEX{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "datatool file"),
      &indexfileformat('dbtex'),
      $_);
}

sub do_cmd_idbtexfile{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('', 
      '<TT>datatool</TT> (<TT>.dbtex</TT>) file',
      &named_index_entry($id, "datatool (.dbtex) file"),
      &indexfileformat('dbtex'),
      $_);
}

sub do_cmd_indexCSV{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "comma-separated variable file"),
      &indexfileformat('csv'),
      $_);
}

sub do_cmd_indexXLS{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "Excel spreadsheet"),
      &indexfileformat('xls'),
      $_);
}

sub do_cmd_indexODS{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "Open Document spreadsheet"),
      &indexfileformat('ods'),
      $_);
}

sub do_cmd_indexODT{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "Open Document Format"),
      &indexfileformat('odt'),
      $_);
}

sub do_cmd_iodtfile{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      '<TT>.odt</TT>',
      &named_index_entry($id, "Open Document Format"),
      &indexfileformat('odt'),
      $_);
}

sub do_cmd_indexTDF{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "ticket definition file"),
      &indexfileformat('tdf'),
      $_);
}

sub do_cmd_indexJDR{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &indexfileformat('jdr'),
      $_);
}

sub do_cmd_indexAJR{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      &indexfileformat('ajr'),
      $_);
}

sub do_cmd_ijdrfile{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      '<TT>.jdr</TT>',
      &indexfileformat('jdr'),
      $_);
}

sub do_cmd_iajrfile{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('',
      '<TT>.ajr</TT>',
      &indexfileformat('ajr'),
      $_);
}

sub do_cmd_iBiBTeX{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('', 
      'BibTeX',
      &named_index_entry($id, "BibTeX"),
      $_);
}

sub do_cmd_iPDFLaTeX{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   join('', 
      'PDFLaTeX',
      &named_index_entry($id, "PDFLaTeX"),
      $_);
}

sub do_cmd_extraindexaux{
   "<tex2html_extraindexaux_deferred>".$_[0];
}

sub do_cmd_deferredextraindexaux{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('', 
      &named_index_entry(++$global{'max_id'}, "file formats!aux@<TT>.aux</TT>|indexdef"),
      $_);
}

sub do_cmd_extraindexsentencespacing{
   "<tex2html_extraindexsentencespacing_deferred>".$_[0];
}

sub do_cmd_deferredextraindexsentencespacing{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};
   my($id2) = ++$global{'max_id'};
   my($id3) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "spacing!French|indexdef"),
      &named_index_entry(++$global{'max_id'}, "spacing!English|indexdef"),
      &named_index_entry(++$global{'max_id'}, "French spacing|idxcrossref$OP$id1${CP}spacing, French$OP$id1$CP"),
      &named_index_entry(++$global{'max_id'}, "English spacing|idxcrossref$OP$id2${CP}spacing, English$OP$id2$CP"),
      &named_index_entry(++$global{'max_id'}, "inter-sentence spacing|idxcrossref$OP$id3${CP}spacing, inter-sentence$OP$id3$CP"),
      $_);
}

sub do_cmd_extraindexshortlong{
   "<tex2html_extraindexshortlong_deferred>".$_[0];
}

sub do_cmd_deferredextraindexshortlong{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};
   my($id2) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "short command|idxcrossref$OP$id1${CP}command, short$OP$id1$CP"),
      &named_index_entry(++$global{'max_id'}, "long command|idxcrossref$OP$id2${CP}command, long$OP$id2$CP"),
      &named_index_entry(++$global{'max_id'}, "command!long|indexdef"),
      $_);
}

sub do_cmd_extraindexfragile{
   "<tex2html_extraindexfragile_deferred>".$_[0];
}

sub do_cmd_deferredextraindexfragile{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   local $id1 = ++$global{'max_id'};
   local $id2 = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "moving argument|idxcrossref$OP$id1${CP}argument, moving$OP$id1$CP"),
      &named_index_entry(++$global{'max_id'}, "argument!moving|indexdef"),
      &named_index_entry(++$global{'max_id'}, "fragile command|idxcrossref$OP$id2${CP}command, fragile$OP$id2$CP"),
      $_);
}

sub do_cmd_extraindexoptional{
   "<tex2html_extraindexoptional_deferred>".$_[0];
}

sub do_cmd_deferredextraindexoptional{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "optional argument|idxcrossref$OP$id1${CP}argument, optional$OP$id1$CP"),
      $_);
}

sub do_cmd_extraindexmandatory{
   "<tex2html_extraindexmandatory_deferred>".$_[0];
}

sub do_cmd_deferredextraindexmandatory{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "mandatory argument|idxcrossref$OP$id1${CP}argument, mandatory$OP$id1$CP"),
      $_);
}

sub do_cmd_extraindexrobust{
   "<tex2html_extraindexrobust_deferred>".$_[0];
}

sub do_cmd_deferredextraindexrobust{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "robust command|idxcrossref$OP$id1${CP}command, robust$OP$id1$CP"),
      $_);
}

sub do_cmd_extraindexarg{
   "<tex2html_extraindexarg_deferred>".$_[0];
}

sub do_cmd_deferredextraindexarg{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "parameter|idxcrossref$OP$id1${CP}argument$OP$id1$CP"),
      $_);
}

sub do_cmd_extraindexgroup{
   "<tex2html_extraindexgroup_deferred>".$_[0];
}

sub do_cmd_deferredextraindexgroup{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "scope|idxcrossref$OP$id1${CP}group$OP$id1$CP"),
      $_);
}

sub do_cmd_extraindexterminal{
   "<tex2html_extraindexterminal_deferred>".$_[0];
}

sub do_cmd_deferredextraindexterminal{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my($id1) = ++$global{'max_id'};

   join('', 
      &named_index_entry(++$global{'max_id'}, "command prompt|idxcrossref$OP$id1${CP}terminal$OP$id1$CP"),
      $_);
}

sub do_cmd_doublequestionmark{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   local $text = &unicode_entity('?');
   $text .= $text;

   join('',
      $text,
      &named_index_entry(++$global{'max_id'}, "$text (undefined reference)"),
      $_);
}

sub do_cmd_Index{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     $text,
      &named_index_entry($id, $text),
      $_);
}

sub do_cmd_Indextt{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<TT>$text</TT>",
      &named_index_entry($id, "$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_indextt{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_indexttdef{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "$text@<TT>$text</TT>|indexdef"),
      $_);
}

sub do_cmd_iboolvar{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<CODE>$text</CODE>",
      &named_index_entry($id, "$text@<CODE>$text</CODE> boolean flag"),
      $_);
}

sub do_cmd_boolvar{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>$text</CODE>" . $_;
}

sub do_cmd_envname{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>$text</CODE>" . $_;
}

sub do_cmd_envdef{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   "<CODE>$text</CODE>\\indexEnvdef $OP$id$CP$text$OP$id$CP" . $_;
}

sub do_cmd_ienvname{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   "<CODE>$text</CODE>\\indexEnv $OP$id$CP$text$OP$id$CP" . $_;
}

sub do_cmd_envopt{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>$text</CODE>" . $_;
}

sub do_cmd_ienvopt{
   local($_) = @_;
   local($list,$text);

   $list = &missing_braces unless
      s/$next_pair_pr_rx/$list=$2;''/eo;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   local($idxstuff) = '';

   foreach my $env (split /,/, $list)
   {
      $idxstuff .= &named_index_entry(++$global{'max_id'}, 
         "$env@<CODE>$env</CODE> environment!$text@<CODE>$text</CODE>");
   }

   "<CODE>$text</CODE>$idxstuff$_";
}

sub do_cmd_cmdname{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   '<CODE>'.&unicode_entity('\\')."$text</CODE>" . $_;
}

sub do_cmd_cmdopt{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>$text</CODE>" . $_;
}

sub do_cmd_icmdopt{
   local($_) = @_;
   local($list,$text);

   $list = &missing_braces unless
      s/$next_pair_pr_rx/$list=$2;''/eo;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   local($idxstuff) = '';

   local $bksl = &unicode_entity('\\');

   foreach my $cmd (split /,/, $list)
   {
      $idxstuff .= &named_index_entry(++$global{'max_id'}, 
         "$cmd@<CODE>$bksl$cmd</CODE>!$text@<CODE>$text</CODE>");
   }

   "<CODE>$text</CODE>$idxstuff$_";
}

sub do_cmd_ipagestyle{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($fmttext) = &translate_commands("\\pagestylefmt $OP$id$CP$text$OP$id$CP");

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
      $fmttext,
      &named_index_entry($id, "page style!$text"),
      $_);
}

sub do_cmd_pagestylefmt{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>$text</CODE>" . $_;
}

sub do_cmd_icounter{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<CODE>$text</CODE>",
      &named_index_entry($id, "counters!$text"),
      $_);
}

sub do_cmd_cmddef{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   local $bksl = &unicode_entity('\\');
   join('',
     "<CODE>$bksl$text</CODE>",
      &named_index_entry($id, "$text@<CODE>$bksl$text</CODE>|indexdef"),
      $_);
}

sub do_cmd_icmdname{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   local $atsym = &unicode_entity('@');
   $text=~s/@/$atsym/g;

   local $bksl = &unicode_entity('\\');
   join('',
     "<CODE>$bksl$text</CODE>",
      &named_index_entry($id, "$text@<CODE>$bksl$text</CODE>"),
      $_);
}

sub do_cmd_indexCom{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};
   local $bksl = &unicode_entity('\\');

   join('',
      &named_index_entry($id, "$text@<CODE>$bksl$text</CODE>"),
      $_);
}

sub do_cmd_indexEnv{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "$text environment@<CODE>$text</CODE> environment"),
      $_);
}

sub do_cmd_indexEnvdef{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "$text environment@<CODE>$text</CODE> environment|indexdef"),
      $_);
}

sub do_cmd_glocsindex{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};
   local $bksl = &unicode_entity('\\');

   join('',
      &named_index_entry($id, "$text@<CODE>$bksl$text</CODE>|indexglo"),
      $_);
}

sub do_cmd_ibst{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<TT>$text</TT>",
      &named_index_entry(++$global{'max_id'}, "$text BibTeX style@<TT>$text</TT> BibTeX style"),
      &named_index_entry(++$global{'max_id'}, "BibTeX styles!$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_ibibentry{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<TT>$text</TT>",
      &named_index_entry($id, "bib entry types!$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_ibibfield{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<TT>$text</TT>",
      &named_index_entry($id, "bib entry fields!$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_isty{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<TT>$text</TT>",
      &named_index_entry(++$global{'max_id'}, "$text package@<TT>$text</TT> package"),
      &named_index_entry(++$global{'max_id'}, "packages!$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_istystart{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
      &named_index_entry(++$global{'max_id'}, "$text package@<TT>$text</TT> package|("),
      &named_index_entry(++$global{'max_id'}, "packages!$text@<TT>$text</TT>|("),
      $_);
}

sub do_cmd_istyend{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
      &named_index_entry(++$global{'max_id'}, "$text package@<TT>$text</TT> package|)"),
      &named_index_entry(++$global{'max_id'}, "packages!$text@<TT>$text</TT>|)"),
      $_);
}

sub do_cmd_icls{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<TT>$text</TT>",
      &named_index_entry(++$global{'max_id'}, "$text class@<TT>$text</TT> class"),
      &named_index_entry(++$global{'max_id'}, "class files!$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_nxiatsym{
  "<tex2html_iatsym_deferred>".$_[0];
}

sub do_cmd_deferrediatsym{
   local($_) = @_;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   local $text = &unicode_entity('@');

   join('',
     "<CODE>$text</CODE>",
      &named_index_entry(++$global{'max_id'}, "$text@<CODE>$text</CODE>"),
      $_);
}

sub do_cmd_nxscrclsopt{
  "<tex2html_scrclsopt_deferred>".$_[0];
}

sub do_cmd_deferredscrclsopt{
   local($_) = @_;
   local($text,$id);

   local($opt,$pat) = &get_next_optional_argument;

   $opt = '='.$opt if ($opt);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$text$opt</CODE>",
      &named_index_entry(++$global{'max_id'}, "KOMA Script class options!$text@<CODE>$text</CODE>"),
      &named_index_entry(++$global{'max_id'}, "class file options!$text@<CODE>$text</CODE>"),
      $_);
}

sub do_cmd_scrclsopt{
   local($_) = @_;
   local($text,$id);

   local($opt,$pat) = &get_next_optional_argument;

   $opt = '='.$opt if ($opt);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$text$opt</CODE>",
      &named_index_entry(++$global{'max_id'}, "KOMA Script class options!$text@<CODE>$text</CODE>"),
      &named_index_entry(++$global{'max_id'}, "class file options!$text@<CODE>$text</CODE>"),
      $_);
}

sub do_cmd_nxclsopt{
  "<tex2html_clsopt_deferred>".$_[0];
}

sub do_cmd_clsopt{
   local($_) = @_;
   local($cls,$opt,$id1, $id2);

   $cls = &missing_braces unless
      s/$next_pair_pr_rx/$id1=$1,$cls=$2;''/eo;

   $opt = &missing_braces unless
      s/$next_pair_pr_rx/$id2=$1,$opt=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$opt</CODE>",
      &named_index_entry(++$global{'max_id'}, 
        "class file options!$opt@<CODE>$opt</CODE> (<TT>$cls</TT> option)"),
      &named_index_entry(++$global{'max_id'}, 
        "$opt@<CODE>$opt</CODE> (<TT>$cls</TT> option)"),
      &named_index_entry(++$global{'max_id'}, 
        "$cls options@<TT>$cls</TT> options!$opt@<CODE>$opt</CODE>"),
      $_);
}

sub do_cmd_genclsopt{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   local $sort = $text;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$text</CODE>",
      &named_index_entry(++$global{'max_id'}, "class file options!$text@<CODE>$text</CODE>"),
      &named_index_entry(++$global{'max_id'}, "$sort@<CODE>$text</CODE>"),
      $_);
}

sub do_cmd_styopt{
   local($_) = @_;
   local($text,$sty,$id);

   $sty = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$sty=$2;''/eo;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$text</CODE>",
      &named_index_entry(++$global{'max_id'}, "$sty package!$text@<CODE>$text</CODE>"),
      &named_index_entry(++$global{'max_id'}, "$text ($sty package)@<CODE>$text</CODE> ($sty package)"),
      $_);
}

sub do_cmd_itikzlibrary{
   local($_) = @_;
   local($name);

   $name = &missing_braces unless
      s/$next_pair_pr_rx/$name=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$name</CODE>",
      &named_index_entry(++$global{'max_id'}, "tikz library@<TT>tikz</TT> library!$name@<CODE>$name</CODE>"),
      $_);
}

sub do_cmd_deferredclsopt{
   local($_) = @_;
   local($cls,$opt,$id1, $id2);

   $cls = &missing_braces unless
      s/$next_pair_pr_rx/$id1=$1,$cls=$2;''/eo;

   $opt = &missing_braces unless
      s/$next_pair_pr_rx/$id2=$1,$opt=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$opt</CODE>",
      &named_index_entry(++$global{'max_id'}, 
        "class file options!$opt@<CODE>$opt</CODE> (<TT>$cls</TT> option)"),
      &named_index_entry(++$global{'max_id'}, 
        "$opt@<CODE>$opt</CODE> (<TT>$cls</TT> option)"),
      &named_index_entry(++$global{'max_id'}, 
        "$cls options@<TT>$cls</TT> options!$opt@<CODE>$opt</CODE>"),
      $_);
}

sub do_cmd_deferredstyopt{
   local($_) = @_;
   local($sty,$opt,$id1, $id2);

   $sty = &missing_braces unless
      s/$next_pair_pr_rx/$id1=$1,$sty=$2;''/eo;

   $opt = &missing_braces unless
      s/$next_pair_pr_rx/$id2=$1,$opt=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$opt</CODE>",
      &named_index_entry(++$global{'max_id'}, 
        "$opt@<CODE>$opt</TT> (<CODE>$sty</TT> option)"),
      &named_index_entry(++$global{'max_id'}, 
        "$sty options@<TT>$sty</TT> options!$opt@<CODE>$opt</CODE>"),
      $_);
}

sub do_cmd_deferreditikzlibrary{
   local($_) = @_;
   local($name);

   $name = &missing_braces unless
      s/$next_pair_pr_rx/$name=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   join('',
     "<CODE>$name</CODE>",
      &named_index_entry(++$global{'max_id'}, 
        "tikz library@<TT>tikz</TT> library!$name@<CODE>$name</CODE>"),
      $_);
}

sub do_cmd_keyvalopt{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<CODE>$text</CODE>" . $_;
}

sub do_cmd_ikeyvalopt{
   local($_) = @_;
   local($text, $opt,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   $opt = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$opt=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};
   local $bksl = &unicode_entity('\\');

   join('',
     "<CODE>$opt</CODE>",
      &named_index_entry($id, "$text@$bksl$text!$opt@<CODE>$opt</CODE>"),
      $_);
}

sub do_cmd_appname{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_appopt{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   local $hyp = &unicode_entity('-');

   "<TT>$hyp$hyp$text</TT>" . $_;
}

sub do_cmd_iappopt{
   local($_) = @_;
   local($text,$app, $opt,$id);

   $app = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$app=$2;''/eo;

   $opt = &missing_braces unless
      s/$next_pair_pr_rx/$opt=$2;''/eo;

   local $hyp = &unicode_entity('-');

   $text = "<TT>$hyp$hyp$opt</TT>";

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     $text,
      &named_index_entry($id, "$app application@<TT>$app</TT> application!$opt\@$text"),
      $_);
}

sub do_cmd_appoptstar{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   local $hyp = &unicode_entity('-');

   "<TT>$hyp$text</TT>" . $_;
}

sub do_cmd_iappoptstar{
   local($_) = @_;
   local($text,$app, $opt,$id);

   $app = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$app=$2;''/eo;

   $opt = &missing_braces unless
      s/$next_pair_pr_rx/$opt=$2;''/eo;

   local $hyp = &unicode_entity('-');

   $text = "<TT>$hyp$opt</TT>";

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     $text,
      &named_index_entry($id, "$app application@<TT>$app</TT> application!$opt\@$text"),
      $_);
}

sub do_cmd_iappname{
   local($_) = @_;
   local($text,$indextext,$pat,$id);

   ($indextext,$pat) = &get_next_optional_argument;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   if ($indextext eq '')
   {
      $indextext = $text
   }

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<TT>$text</TT>",
      &named_index_entry($id, "$indextext application@<TT>$indextext</TT> application"),
      $_);
}

sub do_cmd_iappnamelink{
   local($_) = @_;
   local($text,$url, $insert, $pat);

   ($insert,$pat) = &get_next_optional_argument;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   $url = &missing_braces unless
      s/$next_pair_pr_rx/$url=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<A HREF=\"$url\"><TT>$text</TT></A>",
      &named_index_entry(++$global{'max_id'},
        "$text application@<TT>$text</TT> application"),
       $insert,
      $_);
}

sub do_cmd_directive{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_idirective{
   local($_) = @_;
   local($text,$pat,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<TT>$text</TT>",
      &named_index_entry($id, "arara directives@<TT>arara</TT> directives!$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_theme{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_itheme{
   local($_) = @_;
   local($text,$pat,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<TT>$text</TT>",
      &named_index_entry($id, "beamer themes@<TT>beamer</TT> themes!$text@<TT>$text</TT>"),
      $_);
}

sub do_cmd_ithemetype{
   local($_) = @_;
   local($text,$pat,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "$text theme",
      &named_index_entry($id, "beamer themes@<TT>beamer</TT> themes!$text"),
      $_);
}

sub do_cmd_texdistro{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_itexdistro{
   local($_) = @_;
   local($text,$indextext,$pat,$id);

   ($indextext,$pat) = &get_next_optional_argument;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   if ($indextext eq '')
   {
      $indextext = $text
   }

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
     "<TT>$text</TT>",
      &named_index_entry($id, "$indextext@<TT>$indextext</TT>"),
      &named_index_entry(++$global{'max_id'},
        "TeX Distributions!$indextext@<TT>$indextext</TT>"),
      $_);
}

sub do_cmd_itexdistrolink{
   local($_) = @_;
   local($text, $indextext,$url, $insert, $pat);

   ($insert,$pat) = &get_next_optional_argument;

   $indextext = &missing_braces unless
      s/$next_pair_pr_rx/$indextext=$2;''/eo;

   $url = &missing_braces unless
      s/$next_pair_pr_rx/$url=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my $id = ++$global{'max_id'};

   my $text = &do_cmd_texdistro("$OP$id$CP$indextext$OP$id$CP");

   join('',
     "<A HREF=\"$url\">$text</A>",
      &named_index_entry($id, "$indextext\@$text"),
      &named_index_entry(++$global{'max_id'},
        "TeX Distributions!$indextext\@$text"),
      $insert,
      $_);
}

sub do_cmd_perldistro{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_iperldistro{
   local($_) = @_;
   local($text,$url, $insert, $pat);

   ($insert,$pat) = &get_next_optional_argument;

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   $url = &missing_braces unless
      s/$next_pair_pr_rx/$url=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   my $indextext = &do_cmd_perldistro("$OP$id$CP$text$OP$id$CP");

   join('',
     "<A HREF=\"$url\"><TT>$text</TT></A>",
      &named_index_entry(++$global{'max_id'},
        "$text\@$indextext"),
      $insert,
      $_);
}

sub do_cmd_bibfield{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_sty{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_cls{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_tikzlibrary{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_counter{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_vellipsis{
  "&#x22EE;".$_[0];
}

sub do_cmd_menuto{
   local($_) = @_;
   "&#x2192;".$_;
}

sub do_cmd_menu{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>$text</TT>" . $_;
}

sub do_cmd_startmenu{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   "<TT>Start &#x2192; Programs &#x2192; $text</TT>" . $_;
}

sub do_cmd_graphicspath{
   local($_) = @_;

   local ($paths, $dir);

   @IMAGE_PATH = ();

   $paths = &missing_braces unless
      s/$next_pair_pr_rx/$paths=$2;''/eo;

   while ($paths=~s/$next_pair_pr_rx/$dir=$2;''/eog)
   {
      push @IMAGE_PATH, $dir;
   }

   $_
}

sub do_cmd_tikzchecked{
   local($_) = @_;

   my $img = 'tikzchecked.png';
   my $alt = '[circle with light interior]';

   foreach $path (@IMAGE_PATH)
   {
      if (-e "$path$img")
      {
         $img = $path.$img;
         last;
      }
   }

   my $info = `file "$img"`;

   if ($info=~/(\d+) x (\d+)/)
   {
      $info = "WIDTH=\"$1\" HEIGHT=\"$2\"";
   }
   else
   {
      &write_warnings("file '$img' failed $info");
      $info = '';
   }

   "<IMG ALT=\"$alt\" SRC=\"$img\">$_";
}

sub do_cmd_tikzunchecked{
   local($_) = @_;

   my $img = 'tikzunchecked.png';
   my $alt = '[dark 3D effect filled circle]';

   foreach $path (@IMAGE_PATH)
   {
      if (-e "$path$img")
      {
         $img = $path.$img;
         last;
      }
   }

   my $info = `file "$img"`;

   if ($info=~/(\d+) x (\d+)/)
   {
      $info = "WIDTH=\"$1\" HEIGHT=\"$2\"";
   }
   else
   {
      &write_warnings("file '$img' failed $info");
      $info = '';
   }

   "<IMG $info ALT=\"$alt\" SRC=\"$img\">$_";
}

sub do_cmd_incPgfOrGraphics{
  &do_cmd_incGraphics(@_);
}

sub do_cmd_incFboxPgfOrGraphics{
  &do_cmd_incGraphics(@_);
}

sub do_cmd_incGraphics{
   local($_) = @_;
   local($img, $alt);

   local($opt,$pat) = &get_next_optional_argument;

   $img = &missing_braces unless
      s/$next_pair_pr_rx/$img=$2;''/eo;

   local $result = 'false';

   if ($opt=~s/(?:^|,)\s*result\s*=?\s*([a-z]+)?\s*(?:,|$)//g)
   {
      $result = ($1 ? $1 : 'true');
   }

   if ($opt=~/\balt\s*=\s*([^,]+)/i)
   {
      $alt = $1;
   }
   else
   {
      $alt = '';
      &write_warnings("Image '$img' has no alternative text.");
   }

   if ($alt=~/.html?$/)
   {
      local($file) = "imagedesc/$alt";

      if (-e $file)
      {
         if (open FD, $file)
         {
            $alt = '';

            local($line);

            while ($line = <FD>)
            {
               $line=~s/\\/\&\#x005C;/g;
               $alt .= $line;
            }

            $alt .= ' End of Image.<P>';
            close FD;
         }
         else
         {
            &write_warnings("Can't open '$file' $!");
         }
      }
      else
      {
        &write_warnings("Image description file '$file' doesn't exist");
      }
   }

   foreach $path (@IMAGE_PATH)
   {
      if (-e "$path$img.png" or -e "$path$img-thumbnail.png")
      {
         $img = $path.$img;
         last;
      }
   }

   my $imgtag = '';

   if (-e "$img-thumbnail.png")
   {
      my $info = `file "$img-thumbnail.png"`;

      if ($info=~/(\d+) x (\d+)/)
      {
         $info = "WIDTH=\"$1\" HEIGHT=\"$2\"";
      }
      else
      {
         $info = '';
      }

      if (-e "$img.pdf")
      {
        unless ($alt)
        {
           $alt='Download PDF';
        }

        $imgtag = join('',
          "<A TITLE=\"PDF\" HREF=\"$img.pdf\">&#x21E9;</A>",
          "<OBJECT $info BORDER=2 TYPE=\"image/png\" ",
          "DATA=\"$img-thumbnail.png\">",
          $alt,
          "</OBJECT>");
      }
      else
      {
         unless ($alt)
         {
            $alt='Download full size PNG';
         }

         $imgtag = join('',
            "<A TITLE=\"Full Size PNG\" HREF=\"$img.png\">&#x21E9;</A>",
            "<OBJECT $info BORDER=2 TYPE=\"image/png\" ",
            "DATA=\"$img-thumbnail.png\">",
            $alt,
            "</OBJECT>");
      }
   }
   else
   {
      my $info = `file "$img.png"`;

      if ($info=~/(\d+) x (\d+)/)
      {
         $info = "WIDTH=\"$1\" HEIGHT=\"$2\"";
      }
      else
      {
         $info = '';
      }

      if (-e "$img.pdf")
      {
        unless ($alt)
        {
           $alt='Download PDF';
        }

        $imgtag = join('',
          "<A TITLE=\"PDF\" HREF=\"$img.pdf\">&#x21E9;</A>",
          "<OBJECT $info BORDER=\"2\" TYPE=\"image/png\" DATA=\"$img.png\">",
          $alt,
          "</OBJECT>");
      }
      else
      {
        $imgtag = join('',
          "<OBJECT TYPE=\"image/png\" $info DATA=\"$img.png\">",
          $alt,
          "</OBJECT>");
      }
   }

   if ($result eq 'true')
   {
      $imgtag = &make_result_block($imgtag);
   }

   join('', $imgtag, $_);
}

sub do_cmd_frontmatter{

  join("\n",
  "For the document source and alternative formats of this book, go to",
  "<A HREF=\"../index.shtml\">this book's home page</A>.",
  '<P>',
  $copyrighttext,
  '<HR>',
  $_[0]); 
}


# override default interpretation of \LaTeX (looks a bit ugly in HTML!)

sub do_cmd_LaTeX{
   local($_)=@_;

   "LaTeX".$_;
}

sub do_cmd_pLaTeX{
   local($_)=@_;

   "LaTeX".$_;
}

sub do_cmd_pTeX{
   local($_)=@_;

   "TeX".$_;
}

sub do_cmd_LaTeXe{
   local($_)=@_;

   "LaTeX2e".$_;
}

sub do_cmd_TeX{
   local($_)=@_;

   "TeX".$_;
}

sub do_cmd_BiBTeX{
   local($_)=@_;

   "BibTeX".$_;
}

sub do_cmd_PDFLaTeX{
   local($_)=@_;

   "PDFLaTeX".$_;
}

sub do_cmd_PDFTeX{
   local($_)=@_;

   "PDFTeX".$_;
}

sub do_cmd_LuaTeX{
   local($_)=@_;

   "LuaTeX".$_;
}

sub do_cmd_LuaLaTeX{
   local($_)=@_;

   "LuaLaTeX".$_;
}

sub do_cmd_ConTeXt{
   local($_)=@_;

   "ConTeXt".$_;
}

sub do_cmd_eTeX{
   local($_)=@_;

   "eTeX".$_;
}

sub do_cmd_XeTeX{
   local($_)=@_;

   "XeTeX".$_;
}

sub do_cmd_XeLaTeX{
   local($_)=@_;

   "XeLaTeX".$_;
}

sub do_cmd_subject{
   local($_) = @_;
   local($text);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$text=$2;''/eo;

   $_;
}

sub do_cmd_enter{
   local($_) = @_;
   "<IMG SRC=\"pictures/entersymbol.png\" ALIGN=\"CENTER\" ALT=\"return key symbol\">".$_;
}

sub do_cmd_degrees{
   local($_) = @_;

   local($value);

   $value = &missing_braces unless
     s/$next_pair_pr_rx/$value=$2;''/eo;

   "$value&nbsp;degrees$_";
}

sub do_cmd_inch{
   local($_)=@_;

   "in".$_;
}

sub do_cmd_spunit{
   local($_)=@_;

   "sp".$_;
}

sub do_cmd_ptunit{
   local($_)=@_;

   "pt".$_;
}

sub do_cmd_exunit{
   local($_)=@_;

   "ex".$_;
}

sub do_cmd_emunit{
   local($_)=@_;

   "em".$_;
}

sub do_cmd_milli{
   local($_)=@_;

   "m".$_;
}

sub do_cmd_centi{
   local($_)=@_;

   "c".$_;
}

sub do_cmd_meter{
   local($_)=@_;

   "m".$_;
}

sub do_cmd_metre{
   local($_)=@_;

   "m".$_;
}

sub do_cmd_sp{
   local($_) = @_;

   local($value);

   $value = &missing_braces unless
     s/$next_pair_pr_rx/$value=$2;''/eo;

   '<SUP>'.$value.'</SUP>'.$_
}

sub do_cmd_sb{
   local($_) = @_;

   local($value);

   $value = &missing_braces unless
     s/$next_pair_pr_rx/$value=$2;''/eo;

   '<SUB>'.$value.'</SUB>'.$_
}

sub do_cmd_SI{
   local($_) = @_;

   local($value, $unit);

   $value = &missing_braces unless
     s/$next_pair_pr_rx/$value=$2;''/eo;

   $unit = &missing_braces unless
     s/$next_pair_pr_rx/$unit=$2;''/eo;

   $value.'&nbsp;'.$unit.$_
}

sub do_cmd_si{
   local($_) = @_;

   local($unit);

   $unit = &missing_braces unless
     s/$next_pair_pr_rx/$unit=$2;''/eo;

   $unit.$_
}

sub do_cmd_yen{
   local($_)=@_;

   "&yen;".$_;
}

sub do_cmd_ldots{
   local($_)=@_;

   "&#x2026;".$_;
}

sub do_cmd_texteuro{
   local($_)=@_;

   "&#x20AC;".$_;
}

sub do_cmd_textdollar{
   local($_)=@_;

   "&#x0024;".$_;
}

sub do_cmd_textasciitilde{
   local($_)=@_;

   &unicode_entity('~').$_;
}

sub do_cmd_textasciicircum{
   local($_)=@_;

   &unicode_entity('^').$_;
}

sub do_cmd_supregistered{
   local($_)=@_;

   "&#x00AE;".$_;
}

sub do_cmd_textcopyright{
   local($_)=@_;

   "&#x00A9;".$_;
}

sub do_cmd_textquoteleft{
   local($_)=@_;

   "&#x2018;".$_;
}

sub do_cmd_textquoteright{
   local($_)=@_;

   "&#x2019;".$_;
}

sub do_cmd_textquotedblleft{
   local($_)=@_;

   "&#x201C;".$_;
}

sub do_cmd_textquotedblright{
   local($_)=@_;

   "&#x201D;".$_;
}

sub do_cmd_minus{
   local($_)=@_;

   "&#x2212;".$_;
}

sub do_cmd_cos{
   local($_)=@_;

   "cos".$_;
}

sub do_cmd_sin{
   local($_)=@_;

   "sin".$_;
}

sub do_cmd_arg{
   local($_)=@_;

   "arg".$_;
}

sub do_cmd_lim{
   local($_)=@_;

   "lim".$_;
}

sub do_cmd_mprime{
   local($_)=@_;

   "&#x2032;".$_;
}

sub do_cmd_mdprime{
   local($_)=@_;

   "&#x2033;".$_;
}

sub do_cmd_Delta{
   local($_)=@_;

   "&#x1D6E5;".$_;
}

sub do_cmd_rightarrow{
   local($_)=@_;

   "&#x2192;".$_;
}

sub do_cmd_atilde{
   local($_)=@_;

   "&#x00E3;".$_;
}

sub do_cmd_dash{
   local($_)=@_;

   "&#x2009;&#x2014;&#x2009;".$_;
}

sub do_cmd_cdash{
   local($_)=@_;

   "&#x2009;&#x2014;&#x2009;".$_;
}

sub do_cmd_textemdash{
   local($_)=@_;

   "&#x2014;".$_;
}

sub do_cmd_textendash{
   local($_)=@_;

   "&#x2013;".$_;
}

sub do_cmd_dag{
   local($_)=@_;

   "&#x2020;".$_;
}

sub do_cmd_ddag{
   local($_)=@_;

   "&#x2021;".$_;
}

sub do_cmd_times{
   local($_)=@_;

   " &#x00D7; ".$_;
}

sub do_cmd_TO{
   local($_)=@_;

   "&#x21D2;".$_;
}

sub do_cmd_circledone{
   local($_)=@_;

   "&#x2460;".$_;
}

sub do_cmd_circledtwo{
   local($_)=@_;

   "&#x2461;".$_;
}

sub do_cmd_circledthree{
   local($_)=@_;

   "&#x2462;".$_;
}

sub do_cmd_circledfour{
   local($_)=@_;

   "&#x2463;".$_;
}

sub do_cmd_circledfive{
   local($_)=@_;

   "&#x2464;".$_;
}

sub do_cmd_decorativeopenquote{
   local($_)=@_;

   "&#x275B;".$_;
}

sub do_cmd_samplecsvlist{
   local($_)=@_;

   join(&unicode_entity(','), 
    split /,/, 'Parrot,Canary,Zebra,Arara,Duck').$_;
}

sub do_cmd_samplecsvlistwithempties{
   local($_)=@_;

   join(&unicode_entity(','), 
    split /,/, ',Parrot,Canary,Zebra,,Arara,Duck,').$_;
}

sub do_cmd_samplecsvlistwithspaces{
   local($_)=@_;

   ' '.join(' '.&unicode_entity(',').' ', 
    split /,/, 'Parrot,Canary,Zebra,Arara,Duck').' '.$_;
}

sub do_cmd_xpillustI{
   local($_)=@_;

   "<P><TABLE>
     <TR>
       <TD><A CLASS=\"gls\" HREF=\"summary$EXTN#gls:expandafter\"><TT>&#x005C;expandafter</TT></A></TD>
       <TD><A CLASS=\"gls\" HREF=\"summary$EXTN#gls:docsvlist\"><TT>&#x005C;docsvlist</TT></A></TD>
       <TD><A CLASS=\"gls\" HREF=\"summary$EXTN#gls:expandafter\"><TT>&#x005C;expandafter</TT></A></TD>
     </TR>
     <TR>
       <TD>&#x0020;</TD><TD ALIGN=\"center\">&#x2191;</TD><TD ALIGN=\"center\">&#x2191;</TD>
     </TR>
     <TR>
       <TD>&#x0020;</TD><TD ALIGN=\"center\">".&do_meta('token 1')."</TD><TD ALIGN=\"center\">".&do_meta('token 2')."</TD>
     </TR>
    </TABLE><P>"
   .$_;
}

sub do_cmd_xpillustII{
   local($_)=@_;

   "<P><TABLE>
     <TR>
       <TD><A CLASS=\"gls\" HREF=\"summary$EXTN#gls:expandafter\"><TT>&#x005C;expandafter</TT></A></TD>
       <TD ALIGN=\"right\" STYLE=\"padding-right: 0;\"><A CLASS=\"gls\" HREF=\"summary$EXTN#gls:leftbracechar\"><TT>{</TT></A></TD>
       <TD ALIGN=\"left\" STYLE=\"padding-left: 0;\"><TT>&#x005C;mylist</TT></A></TD>
     </TR>
     <TR>
       <TD COLSPAN=\"2\" ALIGN=\"right\">&#x2197;&#x2009;</TD><TD ALIGN=\"center\">&#x2191;</TD>
     </TR>
     <TR>
       <TD COLSPAN=\"2\" ALIGN=\"right\">".&do_meta('token 1')."</TD><TD ALIGN=\"center\">".&do_meta('token 2')."</TD>
     </TR>
    </TABLE><P>"
   .$_;
}

# Decided not to bother with this. The image tag
# is messing with the titles.
sub make_level_image{
  my ($levelidx) = @_;

  my $img = 'pictures/level'. ($levelidx+1) .'.png';
  my $alt = $LEVELINFO[$levelidx]{'description'};

  unless (-e $img)
  {
     &write_warnings("Can't find image '$img'");
     return $alt;
  }

  my $info = `file "$img"`;

  if ($info=~/(\d+) x (\d+)/)
  {
    $info = "WIDTH=\"$1\" HEIGHT=\"$2\"";
  }
  else
  {
    $info = '';
  }

  "<IMG SRC=\"$img\" $info ALT=\"[$alt]\" TITLE=\"$alt\">";
}

sub do_cmd_basiclevelimg{
  join('', '<SPAN CLASS="level"><SPAN CLASS="basic">',
       $LEVELINFO[0]{'symbol'}, 
       '</SPAN></SPAN>',
       $_[0]);
  #&make_level_image(0).$_[0];
}

sub do_cmd_mediumlevelimg{
  join('', '<SPAN CLASS="level"><SPAN CLASS="medium">',
       $LEVELINFO[1]{'symbol'}, 
       '</SPAN></SPAN>',
       $_[0]);
  #&make_level_image(1).$_[0];
}

sub do_cmd_hardlevelimg{
  join('', '<SPAN CLASS="level"><SPAN CLASS="hard">',
       $LEVELINFO[2]{'symbol'}, 
       '</SPAN></SPAN>',
       $_[0]);
  #&make_level_image(2).$_[0];
}

sub make_span_level{
  my ($levelidx) = @_;

  "<SPAN CLASS=\"level\"><SPAN CLASS=\"$LEVELINFO[$levelidx]{'label'}\">$LEVELINFO[$levelidx]{'symbol'}</SPAN></SPAN>";
}

sub make_div_level{
  my ($levelidx) = @_;

  my $level = $LEVELINFO[$levelidx]{'label'};

  local($id1) = ++$global{'max_id'};
  local($id2) = ++$global{'max_id'};

  "<DIV CLASS=\"level\">\\htmlref$OP$id1$CP\\${level}levelimg$OP$id1$CP$OP$id2${CP}levels$OP$id2$CP</DIV>";
}

sub make_level{
  my ($levelidx) = @_;

  &make_span_level($levelidx);#.&make_div_level($levelidx);
}

sub do_cmd_basiclevel{
  &make_level(0) . $_[0]
}

sub do_cmd_mediumlevel{
  &make_level(1) . $_[0]
}

sub do_cmd_hardlevel{
  &make_level(2) . $_[0]
}

sub do_cmd_warning{
  "<DIV CLASS=\"warning\" TITLE=\"warning\">&#x26A0;</DIV>".$_[0];
}

sub do_cmd_wrong{
   local($_)=@_;

  "<SPAN CLASS=\"incorrect\" TITLE=\"incorrect\">&#x2718;</SPAN>".$_[0];
}

sub do_cmd_correct{
   local($_)=@_;

  "<SPAN CLASS=\"correct\" TITLE=\"correct\">&#x2714;</SPAN>".$_[0];
}

sub do_cmd_comma{
   local($_)=@_;

   ",".$_;
}

sub do_cmd_hyphen{
   local($_)=@_;

   "-".$_;
}

sub do_cmd_dequals{
   local($_)=@_;

   "=".$_;
}

sub do_cmd_dcolon{
   local($_)=@_;

   ":".$_;
}

sub do_cmd_middot{
   local($_)=@_;

   "&#x00B7;".$_;
}

sub do_cmd_oelig{
   local($_)=@_;

   "&#x0153;".$_;
}

sub do_cmd_OElig{
   local($_)=@_;

   "&#x0152;".$_;
}

sub do_cmd_iquestiondowncmd{
   local($_)=@_;

   local($id) = ++$global{'max_id'};

   local ($text) = &unicode_entity('?').&unicode_entity('`');

   "<TT>$text</TT>".&translate_commands(
    "\\index$OP$id$CP$text@<TT>$text</TT> (&#x00BF;)$OP$id$CP").$_;
}

sub do_cmd_iexclamdowncmd{
   local($_)=@_;

   local($id) = ++$global{'max_id'};

   local ($text) = &unicode_entity('!').&unicode_entity('`');

   "<TT>$text</TT>".&translate_commands(
    "\\index$OP$id$CP$text@<TT>$text</TT> (&#x00A1;)$OP$id$CP").$_;
}

sub do_cmd_refstar{
   local($_)=@_;
   local($label,$id);

   $label = &missing_braces unless
              s/$next_pair_pr_rx/($id,$label)=($1,$2);''/eo;

   local($ref_mark) = &get_ref_mark($label,$id);

   $ref_mark.$_;
}

sub do_cmd_figuresref{
   'Figures&nbsp;'.&do_cmd_displayrefs($_[0]);
}

sub do_cmd_tablesref{
   'Tables&nbsp;'.&do_cmd_displayrefs($_[0]);
}

sub do_cmd_tablesrefstar{
   'Tables&nbsp;'.&do_cmd_displayrefs($_[0]);
}

sub do_cmd_sectionsref{
   'Sections&nbsp;'.&do_cmd_displayrefs($_[0]);
}

sub do_cmd_displayrefs{
   local($_)=@_;
   local($list,$id);

   $list = &missing_braces unless
     s/$next_pair_pr_rx/$list=$2;''/eo;

   local @reflist = split /,/, $list;

   local $refs = '';

   for (my $idx = 0; $idx <= $#reflist; $idx++)
   {
      $id = ++$global{'max_id'};

      $refs .= &translate_commands("\\ref$OP$id$CP".$reflist[$idx]."$OP$id$CP");

      if ($idx == $#reflist-1)
      {
         $refs .= ' and ';
      }
      elsif ($idx < $#reflist-1)
      {
         $refs .= ', ';
      }
   }

   $refs.$_;
}

$nodename='';

my $nodelist = ',';

sub do_cmd_setnode{
  local($_) = @_;

  local($id);

  $nodename = &missing_braces unless
    s/$next_pair_pr_rx/$id=$1,$nodename=$2;''/eo;

  if ($nodelist=~/,$nodename,/)
  {
     $nodename = '';
  }
  else
  {
     $nodelist .= "$nodename,";
  }

  $_;
}

sub custom_title_hook{
   local($title) = @_;

   local($name) = $nodename;

   unless ($name)
   {
      $name = $title;

      # strip the difficulty level indicator
      $name=~s|<SPAN CLASS="level"><SPAN CLASS="[a-z]+">&#x[\dA-E]+;</SPAN></SPAN>||;

      $name = lc($name);
      $name=~s/[^\w]//g;

      $name=~s/^\d+//;
   }

   $nodename = '';

   $name
}

sub make_name {
    local($sec_name, $packed_curr_sec_id) = @_;
    local($title,$making_name,$saved) = ('',1,'');
    if ($LONG_TITLES) {
        $saved = $_;
        &set_sectioning_title($_) if /^$sections_rx/; # modified
        $title = &make_long_title($TITLE)
            unless ((! $TITLE) || ($TITLE eq $default_title));
        $_ = $saved;
    } elsif ($CUSTOM_TITLES) {
        $saved = $_;
        &set_sectioning_title($_) if /^$sections_rx/; # modified
        $title = &custom_title_hook($TITLE);
        $_ = $saved;
    }
    if ($title) {
        #ensure no more than 32 characters, including extension
        $title =~ s/^(.{1,27}).*$/$1/;
        ++$OUT_NODE;
        join("", ${PREFIX}, $title, $EXTN);
    } else {
    # Remove 0's from the end of $packed_curr_sec_id
        $packed_curr_sec_id =~ s/(_0)*$//;
        $packed_curr_sec_id =~ s/^\d+$//o; # Top level file
        join("",($packed_curr_sec_id ?
            "${PREFIX}$NODE_NAME". ++$OUT_NODE : $sec_name), $EXTN);
    }
}

sub set_sectioning_title{
  local($_) = @_;

  if (/$section_rx/)
  {
    ($before, $cmd, $after) = ($`, $1.$2, $4.$');

    if (defined($unnumbered_section_commands{$cmd}))
    {
       &process_command($section_rx, $_[0]);
    }
    elsif ($cmd eq 'listofexamples')
    {
       $TITLE = "List of Examples";
    }
    elsif ($cmd eq 'listofexercises')
    {
       $TITLE = "List of Exercises";
    }
    else
    {
       local($align, $dummy) = &get_next_optional_argument;

       $TITLE = &missing_braces
           unless $after=~s/$next_pair_rx/$TITLE=$2;''/eo;
    }

    $br_id = ++$global{'max_id'};
    $TITLE = &translate_environments("$O$br_id$C$TITLE$O$br_id$C");
    $TITLE = &simplify($TITLE);
  }
}

# Strip level marker from TITLE tag
#sub custom_TITLE_hook{
#  local($title, $toc_sec_title) = @_;
#
#  $title = $toc_sec_title if ($toc_sec_title);
#
#  for (my $idx = 0; $idx <= $#LEVELINFO; $idx++)
#  {
#     last if $title=~s/^([\d\.]+ )?$LEVELINFO[$idx]{'symbol'}/$1/;
#  }
#
#  $title;
#}

%sectiontitles = ();


sub do_cmd_sectionlabel{
    local($_) = @_;
    local($label, $title);

    $label = &missing_braces unless (
        (s/$next_pair_pr_rx/$label = $2;''/eo)
        ||(s/$next_pair_rx/$label = $2;''/eo));

    $title = &missing_braces unless (
        (s/$next_pair_pr_rx/$title = $2;''/eo)
        ||(s/$next_pair_rx/$title = $2;''/eo));

    $sectiontitles{$label}=$title;

    &anchor_label($label,$CURRENT_FILE,$_);
}

sub do_cmd_xrsectionref{
   local($_) = @_;

   local($label,$pat) = &get_next_optional_argument;

   local($text,$html);

   $text = &missing_braces unless
       s/$next_pair_pr_rx/$text = $2;''/eo;

   $html = &missing_braces unless
       s/$next_pair_pr_rx/$html = $2;''/eo;

   $html .= $EXTN;

   $html .= "#$label" if $label;

   "<A HREF=\"\\baseurl/latex/novices/html/$html\">$text</A>".$_
}

sub do_cmd_sectionref{
   local($_) = @_;

   local($text,$pat) = &get_next_optional_argument;

   local($label, $id);

   $label = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$label = $2;''/eo;

   local($id2) = ++$global{'max_id'};

   unless ($text)
   {
      local ($num) = $symbolic_labels{$label};

      $text = $sectiontitles{$label} ? 
              $sectiontitles{$label} :
              $label;

      $text=~s|<SPAN CLASS="level"><SPAN CLASS="[a-z]+">[^<]+</SPAN></SPAN>||;

      $text=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      if ($num)
      {
         $text = "\\S " . $num. " " . $text;
      }
   }

   "\\htmlref$OP$id$CP$text$OP$id$CP$OP$id2$CP$label$OP$id2$CP".$_;
}

sub do_cmd_chapterref{
  &do_cmd_sectionref(@_);
}

sub do_cmd_appendixref{
   local($_) = @_;

   local($text,$pat) = &get_next_optional_argument;

   local($label, $id);

   $label = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$label = $2;''/eo;

   local($id2) = ++$global{'max_id'};

   unless ($text)
   {
      local ($num) = $symbolic_labels{$label};

      $text = $sectiontitles{$label} ? 
              $sectiontitles{$label} :
              $label;

      $text=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      if ($num)
      {
         $text = "Appendix " . $num. ". " . $text;
      }
   }

   "\\htmlref$OP$id$CP$text$OP$id$CP$OP$id2$CP$label$OP$id2$CP".$_;
}

sub do_cmd_authordetails{
   local($_) = @_;

   local($dob, $surname, $forenames, $id);

   $dob = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$dob = $2;''/eo;

   $surname = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$surname = $2;''/eo;

   $forenames = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$forenames = $2;''/eo;

   $t_author = join(' ', $forenames, $surname);

   push @authors, $t_author;

   $_
}

sub do_cmd_affiliation{
   local($_) = @_;

   local($url, $address, $id);

   $t_affil = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$t_affil = $2;''/eo;

   $url = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$url = $2;''/eo;

   $address = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$address = $2;''/eo;

   $t_address = "<A HREF=\"$url\"><TT>$url</TT></A>";

   push @affils, $t_affil;
   push @addresses, $t_address;

   $_
}

sub do_cmd_version{
   local($_) = @_;

   local($theversion, $id);

   $theversion = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$theversion = $2;''/eo;

   $t_date = "Version $theversion";

   $_
}

my($t_series, $t_volume, $t_edition) = ();

sub do_cmd_edition{
   local($_) = @_;

   local($id);

   $t_edition = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$t_edition = $2;''/eo;

   $_
}

sub do_cmd_volume{
   local($_) = @_;

   local($id);

   $t_volume = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$t_volume = $2;''/eo;

   $_
}

sub do_cmd_series{
   local($_) = @_;

   local($id);

   $t_series = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$t_series = $2;''/eo;

   $_
}

sub do_cmd_seriesurl{
   local($_) = @_;

   local($id);

   $t_seriesurl = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$t_seriesurl = $2;''/eo;

   $t_homepage = $t_seriesurl;

   $t_homepage=~s|^(https?://[^/]+)/.*$|$1/|;

   $_
}

$copyrighttext = '';

sub do_cmd_copyrighttext{
   local($_) = @_;

   $copyrighttext = &missing_braces unless
     s/$next_pair_pr_rx/$copyrighttext=$2;''/eo;

   $_;
}

eval(<<'_END_EVAL');
sub do_cmd_maketitle{
   local($after) = @_;
   local($the_title) = '';

   if ($t_title)
   {
     $the_title = "<H1 ALIGN=CENTER>$t_title</H1>\n";
   }
   else
   {
      &write_warnings("This document has no title.");
   }

   if (($#authors > 0)||$MULTIPLE_AUTHOR_TABLE)
   {
        $the_title .= &make_multipleauthors_title($alignc,$alignl);
   }
   else
   {
     $the_title .= &make_singleauthor_title($alignc,$alignl,$t_author,
       $t_affil,$t_institute,$t_date,$t_address,$t_email,$t_authorURL);
   }

   if (($t_translator)&&!($t_translator=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/))
   {
      $the_title .= "<BR><P ALIGN=CENTER>Translated by $t_translator</P>\n";
   }

   if (($t_version)&&!($t_version=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/))
   {
      $the_title .= "<BR><P ALIGN=CENTER>$t_version</P>\n";
   }

   if (($t_date)&&!($t_date=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/))
   {
      $the_title .= "<BR><P ALIGN=CENTER>$t_date</P>\n";
   }

   if ($t_volume && $t_series)
   {
      local($seriestext) = "<EM>$t_series</EM>";

      if ($t_seriesurl)
      {
         $seriestext = "<A HREF=\"$t_seriesurl\">$seriestext</A>";
      }

      $the_title .= "<BR><P ALIGN=CENTER>Volume $t_volume of $seriestext</P>\n";
   }

   if ($t_keywords)
   {
     $the_title .= "<BR><P><P ALIGN=LEFT><FONT SIZE=-1>".
            "Key words and phrases: $t_keywords</FONT></P>\n";
   }

    join("\n", $the_title, '<P>',
        $after);
}

sub make_real_glossary_entry {
    local($entry,$text,$type) = @_;
    local($this_file) = $CURRENT_FILE;

    $TITLE = $saved_title
       if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

    # Save the reference
    local($str) = "$label###" . ++$global{'max_id'}; # Make unique

    local($id) = ++$glsentry{$entry}{'maxid'};
    local($glsanchor)="gls:$entry$id";

    local($target) = $frame_body_name;

    if (defined($frame_main_suffix))
    {
       $this_file=~s/$frame_main_suffix/$frame_body_suffix/;
    }

    $glossary{$type}{$str} .= &make_half_href($this_file."#$glsanchor");
    $glossary_format{$type}{$str} = $GLSCURRENTFORMAT;
    $glossary_entry{$type}{$str} = $entry;
    $glossary_linktext{$type}{$str} = $TITLE;

    local($mark) = $gls_file_mark{$type};

    $mark = &get_gls_file_mark($type, $entry) if (defined(&get_gls_file_mark));

    $text = &translate_commands($text);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

    if (defined($frame_foot_name))
    {
       "$anchors<A CLASS=\"gls\" HREF=\"$mark#gls:$entry\" NAME=\"$glsanchor\" TARGET=\"$frame_foot_name\">$text<\/A>";
    }
    else
    {
       "$anchors<A CLASS=\"gls\" HREF=\"$mark#gls:$entry\" NAME=\"$glsanchor\">$text<\/A>";
    }
}

sub make_real_glossary_entry_no_backlink {
    local($entry,$text,$type) = @_;
    local($this_file) = $CURRENT_FILE;

    local($target) = $frame_body_name;

    if (defined($frame_main_suffix))
    {
       $this_file=~s/$frame_main_suffix/$frame_body_suffix/;
    }

    local($mark) = $gls_file_mark{$type};

    $mark = &get_gls_file_mark($type, $entry) if (defined(&get_gls_file_mark));

    $text = &translate_commands($text);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

    if (defined($frame_foot_name))
    {
       "$anchors<A CLASS=\"gls\" HREF=\"$mark#gls:$entry\" NAME=\"$glsanchor\" TARGET=\"$frame_foot_name\">$text<\/A>";
    }
    else
    {
       "$anchors<A CLASS=\"gls\" HREF=\"$mark#gls:$entry\" >$text<\/A>";
    }
}

sub do_cmd_glshyperlink{
   local($_) = @_;

   local($text,$pat) = &get_next_optional_argument;

   local($id, $label);

   $label = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $text = &gls_get_text($label) unless $text;

   local($type) = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text<\/A>"
   .$_;
}

_END_EVAL

sub do_cmd_boldc{
  join('', '<B><EM>c</EM></B>', @_[0]);
}

sub do_cmd_dag{
  join('', '&#x2020;', @_[0]);
}

sub do_cmd_ddag{
  join('', '&#x2021;', @_[0]);
}

sub do_cmd_supdag{
  join('', '<SUP>&#x2020;</SUP>', @_[0]);
}

sub do_cmd_supddag{
  join('', '<SUP>&#x2021;</SUP>', @_[0]);
}

sub do_cmd_supdagddag{
  join('', '<SUP>&#x2020;&#x2021;</SUP>', @_[0]);
}

sub do_cmd_backslashsym{

  join('', '&#x005C;', @_[0]);
}

sub do_cmd_dbbackslashsym{
  join('', '&#x005C;&#x005C;', @_[0]);
}

sub do_cmd_emDashcs{
  local $hyp = &unicode_entity('-');
  join('', $hyp, $hyp, $hyp, @_[0]);
}

sub do_cmd_enDashcs{
  local $hyp = &unicode_entity('-');
  join('', $hyp, $hyp, @_[0]);
}

sub do_cmd_dashcs{
  join('', &unicode_entity('-'), @_[0]);
}

sub do_cmd_pluscs{
  join('', &unicode_entity('+'), @_[0]);
}

sub do_cmd_quoteleftcs{
  join('', &unicode_entity('`'), @_[0]);
}

sub do_cmd_quotedblleftcs{
  local $grave = &unicode_entity('`');
  join('', $grave, $grave, @_[0]);
}

sub do_cmd_quoterightcs{
  join('', &unicode_entity("'"), @_[0]);
}

sub do_cmd_quotedblrightcs{
  local $apos = &unicode_entity("'");
  join('', $apos, $apos, @_[0]);
}

sub do_cmd_questiondowncs{
  join('', &unicode_entity('?'), &unicode_entity('`'), @_[0]);
}

sub do_cmd_exclamdowncs{
  join('', &unicode_entity('!'), &unicode_entity('`'), @_[0]);
}

sub do_cmd_exclamsym{
  join('', &unicode_entity('!'), @_[0]);
}

sub do_cmd_slash{
  join('', &unicode_entity('/'), @_[0]);
}

sub do_cmd_slashsym{
  join('', &unicode_entity('/'), @_[0]);
}

sub do_cmd_openparensym{
  join('', &unicode_entity('('), @_[0]);
}

sub do_cmd_closeparensym{
  join('', &unicode_entity(')'), @_[0]);
}

sub do_cmd_opensqsym{
  join('', &unicode_entity('['), @_[0]);
}

sub do_cmd_closesqsym{
  join('', &unicode_entity(']'), @_[0]);
}

sub do_cmd_commasym{
  join('', &unicode_entity(','), @_[0]);
}

sub do_cmd_colonsym{
  join('', &unicode_entity(':'), @_[0]);
}

sub do_cmd_semicolonsym{
  join('', &unicode_entity(';'), @_[0]);
}

sub do_cmd_lesssym{
  join('', &unicode_entity('<'), @_[0]);
}

sub do_cmd_greatersym{
  join('', &unicode_entity('>'), @_[0]);
}

sub do_cmd_periodsym{
  join('', &unicode_entity('.'), @_[0]);
}

sub do_cmd_equalsym{
  join('', &unicode_entity('='), @_[0]);
}

sub do_cmd_underscoresym{
  join('', &unicode_entity('_'), @_[0]);
}

sub do_cmd_textunderscore{
  join('', &unicode_entity('_'), @_[0]);
}

sub do_cmd_tildesym{
  join('', &unicode_entity('~'), @_[0]);
}

sub do_cmd_circumsym{
  join('', &unicode_entity('^'), @_[0]);
}

sub do_cmd_quotecs{
  join('', &unicode_entity('\\'), &unicode_entity('"'), @_[0]);
}

sub do_cmd_doublequotesym{
  join('', &unicode_entity('"'), @_[0]);
}

sub do_cmd_mathsingleprime{
  join('', '&#x2032;', @_[0]);
}

sub do_cmd_mathtilde{
  join('', '&#x223C;', @_[0]);
}

sub do_cmd_mathwedge{
  join('', '&#x2227;', @_[0]);
}

sub do_cmd_mathvee{
  join('', '&#x2228;', @_[0]);
}

sub do_cmd_mathequiv{
  join('', '&#x2263;', @_[0]);
}

sub do_cmd_mathsum{
  join('', '&#x2211;', @_[0]);
}

sub do_cmd_mathlvert{
  join('', &unicode_entity('|'), @_[0]);
}

sub do_cmd_mathrvert{
  join('', &unicode_entity('|'), @_[0]);
}

sub do_cmd_mathepsilon{
  join('', '&#x1D6DC;', @_[0]);
}

sub do_cmd_mathleftarrow{
  join('', '&#x2190;', @_[0]);
}

sub do_cmd_mathdoubleprime{
  join('', '&#x2033;', @_[0]);
}

sub do_cmd_mathcalS{
  join('', '&#x1D4E2;', @_[0]);
}

sub do_cmd_ocaron{
  join('', '&#x01D2;', @_[0]);
}

sub do_cmd_ocedilla{
  join('', '&#x01EB;', @_[0]);
}

sub do_cmd_odotunder{
  join('', '&#x1ECD;', @_[0]);
}

sub do_cmd_omacron{
  join('', '&#x014D;', @_[0]);
}

sub do_cmd_odoubleacute{
  join('', '&#x0150;', @_[0]);
}

sub do_cmd_odotover{
  join('', '&#x022F;', @_[0]);
}

sub do_cmd_oumlaut{
  join('', '&#x00F6;', @_[0]);
}

sub do_cmd_otilde{
  join('', '&#x00F5;', @_[0]);
}

sub do_cmd_ocircum{
  join('', '&#x00F4;', @_[0]);
}

sub do_cmd_obreve{
  join('', '&#x014F;', @_[0]);
}

sub do_cmd_uring{
  join('', '&#x016F;', @_[0]);
}

sub do_cmd_rbarunder{
  join('', '&#x1E5F;', @_[0]);
}

sub do_cmd_xytie{
  join('', 'x&#x0361;y', @_[0]);
}

sub do_cmd_dotlessj{ "&#x0237;".$_[0]; }

sub do_cmd_textvisiblespace{
  join('', '&#x2423;', @_[0]);
}

sub do_cmd_preambleillustration{
<<_END_TEXT;
<PRE>
&#x005C;documentclass{...}

                    &#x2B05; <EM>This bit here is the preamble</EM>

&#x005C;begin{document}
</PRE>
   $_[0]
_END_TEXT
}

sub do_cmd_nonodesubsection{
   local($_) = @_;
   local($title);

   $title = &missing_braces unless
       s/$next_pair_pr_rx/$title = $2;''/eo;

   "<H3>$title</H3>$_";
}

sub do_cmd_xminisec{
   local($_) = @_;

   local($id,$title);

   $title = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$title = $2;''/eo;

   "<P><B>$title</B><P>$_";
}

sub do_cmd_refstar{
  local($_) = @_;
  local($label, $id);

  $label = &missing_braces unless
    s/$next_pair_pr_rx/($id,$label);''/eo;

  local($ref_mark) = &get_ref_mark($label, $id);

  $ref_mark.$_;
}

sub meta_information{
  local($_) = @_;

  local($keywords) = (defined($t_keywords) ? $t_keywords : $FILE);

  # Can't have nested HTML tags...

  do
  {
    s/<[^>]*>//g;
    "<META NAME=\"description\" CONTENT=\"$_\">\n" .
    "<META NAME=\"keywords\" CONTENT=\"$keywords\">\n" .
    "<META NAME=\"resource-type\" CONTENT=\"document\">\n" .
    "<META NAME=\"distribution\" CONTENT=\"global\">\n"
  }
  if $_;
}

sub do_cmd_historyitem{
   local($_) = @_;

   local($text);

   $text = &missing_braces unless 
    s/$next_pair_pr_rx/$text=$2;''/eo;

   "<H2>$text</H2>$_";
}

sub do_cmd_keywordfmt{
   local($_) = @_;

   local($text);

   $text = &missing_braces unless
     s/$next_pair_pr_rx/$text=$2;''/eo;

   "<EM>$text</EM>".$_;
}

eval(<<'_END_EVAL');
sub do_cmd_glsdisplay{
   local($_) = @_;
   local($text,$description,$symbol,$insert);

   $text = &missing_braces unless
        (s/$next_pair_pr_rx/$text=$2;''/eo);

   $description = &missing_braces unless
        (s/$next_pair_pr_rx/$description=$2;''/eo);

   $description =~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   $symbol = &missing_braces unless
        (s/$next_pair_pr_rx/$symbol=$2;''/eo);

   $insert = &missing_braces unless
        (s/$next_pair_pr_rx/$insert=$2;''/eo);

   $text = "$text$insert";

   $text = &translate_commands($text);

   $text =~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   $text = &translate_commands($text);

   $text . $_;
}

sub do_cmd_glsdisplayfirst{
   local($_) = @_;
   local($text,$description,$symbol,$insert);

   $text = &missing_braces unless
        (s/$next_pair_pr_rx/$text=$2;''/eo);

   $description = &missing_braces unless
        (s/$next_pair_pr_rx/$description=$2;''/eo);

   $description =~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   $symbol = &missing_braces unless
        (s/$next_pair_pr_rx/$symbol=$2;''/eo);

   $insert = &missing_braces unless
        (s/$next_pair_pr_rx/$insert=$2;''/eo);

   $text = "$text$insert";

   $text = &translate_commands($text);

   $text =~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   $text = &translate_commands($text);

   $text . $_;
}
_END_EVAL

sub do_cmd_glsindex{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

   my ($text) = &gls_get_user($label, 5);

   join('', $text, $_);
}

sub do_cmd_indexglsindex{
  "<tex2html_indexglsindex_deferred>".$_[0];
}

sub do_cmd_deferredindexglsindex{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   my ($idxtext) = &gls_get_user($label, 5);

   $id = ++$global{'max_id'};

   join('',
        &named_index_entry($id, $idxtext),
        $_);
}

sub do_cmd_glsextra{
  &do_cmd_glsentryuservi(@_);
}

sub do_cmd_glsterm{
  &do_cmd_glsuseriv(@_);
}

sub do_cmd_glsd{
   local($_) = @_;

   local($id, $label);

   local($keyval,$pat) = &get_next_optional_argument;

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

   local($text) = '';

   if (&gls_used($label))
   {
      local($this_file) = $CURRENT_FILE;

      $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

      my ($idxtext) = &gls_get_user($label, 5);

      $id = ++$global{'max_id'};

      $text = join('',
                &do_cmd_glsuseri("[$keyval]$OP$id$CP$label$OP$id$CP"),
                &named_index_entry(++$global{'max_id'}, $idxtext)
                );
   }
   else
   {
      $text = join('', "<EM>", &gls_get_user($label, 1), "</EM>");
      &unset_entry($label);
   }

   $text.$_;
}

sub do_cmd_glsing{
   local($_) = @_;

   local($id, $label);

   local($keyval,$pat) = &get_next_optional_argument;

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

   local($text) = '';

   if (&gls_used($label))
   {
      local($this_file) = $CURRENT_FILE;

      $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

      my ($idxtext) = &gls_get_user($label, 5);

      $id = ++$global{'max_id'};

      $text = join('',
                &do_cmd_glsuserii("[$keyval]$OP$id$CP$label$OP$id$CP"),
                &named_index_entry(++$global{'max_id'}, $idxtext)
             );
   }
   else
   {
      $text = join('', "<EM>", &gls_get_user($label, 2), "</EM>");
      &unset_entry($label);
   }

   $text.$_;
}

sub do_cmd_kglossaryentryfield{
   local($_) = @_;

   local($id, $label, $name, $desc, $symbol, $backlink);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

   $name = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$name=$2;''/eo;

   $desc = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$desc=$2;''/eo;

   $symbol = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$symbol=$2;''/eo;

   $backlink = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$backlink=$2;''/eo;

   local($idx) = &translate_commands("\\glsindex $OP$id$CP$label$OP$id$CP");

   if ($idx)
   {
      $idx = &named_index_entry(++$global{'max_id'}, $idx);
   }

   local($userkey) = &do_cmd_glsextrakey('');

   local($extra) = $glsentry{$label}{$userkey};

   $extra=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   $desc=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   join('', $idx, $extra, $desc, "\n", $_);
}

sub do_cmd_kglossarysubentryfield{
   local($_) = @_;

   local($id, $level, $label, $name, $desc, $symbol, $backlink);

   $level = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$level=$2;''/eo;

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

   $name = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$name=$2;''/eo;

   $desc = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$desc=$2;''/eo;

   $symbol = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$symbol=$2;''/eo;

   $backlink = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1;$backlink=$2;''/eo;

   local($idx) = &translate_commands("\\glsindex $OP$id$CP$label$OP$id$CP");

   if ($idx)
   {
      $idx = &named_index_entry(++$global{'max_id'}, $idx);
   }

   my $key = &do_cmd_glsextrakey('');

   local($extra) = $glsentry{$label}{$key};

   $extra=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   $desc=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

   join('', $idx, $extra, $desc, "\n", $_);
}

sub get_gls_file_mark{
   local($type, $entry) = @_;

   $gls_file_mark{$type};
}

sub do_cmd_newabbr{
   local($_) = @_;

   local($label, $abbrv, $long, $url, $id);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $abbrv = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$abbrv=$2;''/eo;

   my $sort = $abbrv;

   $long = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$long=$2;''/eo;

   $url = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$url=$2;''/eo;

   &make_newacr($label, $abbrv, $long, $url, 'ABBR');
}

sub do_cmd_newacr{
   local($_) = @_;

   local($label, $abbrv, $long, $url, $id);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $abbrv = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$abbrv=$2;''/eo;

   my $sort = $abbrv;

   $long = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$long=$2;''/eo;

   $url = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$url=$2;''/eo;

   &make_newacr($label, $abbrv, $long, $url, 'ACRONYM');
}

sub make_newacr{
   local($label, $abbrv, $long, $url, $tag) = @_;

   local $id = ++$global{'max_id'};

   local($name) = "$abbrv<tex2html_gloindex_deferred> $OP$id$CP$abbrv$OP$id$CP";

   local($desc) = &do_real_makefirstuc($long).". <A HREF=\"$url\"><TT>$url</TT></A>.";

   $id = ++$global{'max_id'};

   local($first) = "$long ($abbrv)\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   $id = ++$global{'max_id'};

   local($firstplural) = "${long}s (${abbrv}s)\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   $id = ++$global{'max_id'};

   local($text) = "<$tag title=\"$long\">$abbrv</$tag>\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   $id = ++$global{'max_id'};

   local($plural) = "<$tag title=\"${long}s\">${abbrv}s</$tag>\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   &gls_entry_init($label, $acronymtype, $name, $desc);

   &gls_set_sort($label, $sort);

   &gls_set_first($label, $first);
   &gls_set_firstplural($label, $firstplural);

   &gls_set_text($label, $text);
   &gls_set_plural($label, $plural);

   &gls_set_useriv($label, $text);

   push @{$gls_entries{$acronymtype}}, $label;

   $_;
}

sub do_cmd_newacrnourl{
   local($_) = @_;

   local($opt1) = &get_next_optional_argument;
   local($opt2) = &get_next_optional_argument;

   local($label, $abbrv, $long, $id, $shortplural, $longplural);

   ($longplural,$opt2) = &get_keyval('longplural', $opt2);
   ($shortplural,$opt2) = &get_keyval('shortplural', $opt2);


   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $abbrv = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$abbrv=$2;''/eo;

   my $sort = $abbrv;

   $long = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$long=$2;''/eo;

   if ($longplural)
   {
      $opt1 = " (plural: $longplural)".$opt1;
   }
   else
   {
      $longplural = $long.'s';
   }

   $shortplural = $abbrv.'s' unless ($shortplural);

   &make_newacrnourl($label, $abbrv, $long, $shortplural, $longplural, 
    'ACRONYM');
}

sub do_cmd_newabbrnourl{
   local($_) = @_;

   local($opt1) = &get_next_optional_argument;
   local($opt2) = &get_next_optional_argument;

   local($label, $abbrv, $long, $id, $shortplural, $longplural);

   ($longplural,$opt2) = &get_keyval('longplural', $opt2);
   ($shortplural,$opt2) = &get_keyval('shortplural', $opt2);


   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $abbrv = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$abbrv=$2;''/eo;

   my $sort = $abbrv;

   $long = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$long=$2;''/eo;

   if ($longplural)
   {
      $opt1 = " (plural: $longplural)".$opt1;
   }
   else
   {
      $longplural = $long.'s';
   }

   $shortplural = $abbrv.'s' unless ($shortplural);

   &make_newacrnourl($label, $abbrv, $long, $shortplural, $longplural, 
    'ABBR');
}

sub make_newacrnourl{
   local($label, $abbrv, $long, $shortplural, $longplural, $tag) = @_;

   local $id = ++$global{'max_id'};

   local($name) = "$abbrv<tex2html_gloindex_deferred> $OP$id$CP$abbrv$OP$id$CP";

   local($desc) = &do_real_makefirstuc($long).$opt1.'.';

   $id = ++$global{'max_id'};

   local($first) = "$long ($abbrv)\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   $id = ++$global{'max_id'};

   local($firstplural) = "${longplural} (${shortplural})\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   $id = ++$global{'max_id'};

   local($text) = "<$tag title=\"$long\">$abbrv</$tag>\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   $id = ++$global{'max_id'};

   local($plural) = "<$tag title=\"$longplural\">${shortplural}</$tag>\\deferredindex $OP$id$CP$abbrv$OP$id$CP";

   &gls_entry_init($label, $acronymtype, $name, $desc);

   &gls_set_sort($label, $sort);

   &gls_set_first($label, $first);
   &gls_set_firstplural($label, $firstplural);

   &gls_set_text($label, $text);
   &gls_set_plural($label, $plural);

   &gls_set_useriv($label, $text);

   push @{$gls_entries{$acronymtype}}, $label;

   $_;
}

sub do_cmd_newterm{
   local($_) = @_;

   local($plural) = &get_next_optional_argument;

   local($label, $term, $desc, $id);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $term = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$term=$2;''/eo;

   local($name) = $term;

   my $sort = $term;

   $name=~s/\b([a-z]+)/ucfirst($1)/ge;

   $desc = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$desc=$2;''/eo;

   $name .= "<tex2html_gloindex_deferred>$OP$id$CP$term$OP$id$CP";

   local($text) = "$term\\deferredindex $OP$id$CP$term$OP$id$CP";

   &gls_entry_init($label, $acronymtype, $name, $desc);

   &gls_set_sort($label, $sort);

   $plural = $term.'s' unless $plural;

   &gls_set_symbol($label, $plural);

   $plural = "${plural}\\deferredindex $OP$id$CP$term$OP$id$CP";

   &gls_set_first($label, $text);
   &gls_set_firstplural($label, $plural);

   &gls_set_text($label, $text);
   &gls_set_plural($label, $plural);

   &gls_set_useriv($label, $term);

   push @{$gls_entries{$acronymtype}}, $label;

   $_;
}

sub do_cmd_defapp{
   local($_) = @_;

   local($label, $term, $desc, $url, $id, $pat);

   ($label,$pat) = &get_next_optional_argument;

   $term = &missing_braces unless
     s/$next_pair_pr_rx/$term=$2;''/eo;

   my $sort = $term;

   $label = $term unless $label;

   $desc = &missing_braces unless
     s/$next_pair_pr_rx/$desc=$2;''/eo;

   $url = &missing_braces unless
     s/$next_pair_pr_rx/$url=$2;''/eo;

   $desc .= " URL: <A HREF=\"$url\">$url</A>";

   $id = ++$global{'max_id'};

   local($name) = "<TT>$term</TT><tex2html_gloindex_deferred>$OP$id$CP$term\@<TT>$term</TT>$OP$id$CP";

   $id = ++$global{'max_id'};

   local($text) = "<TT>$term</TT>\\deferredindex $OP$id$CP$term\@<TT>$term</TT>$OP$id$CP";

   $id = ++$global{'max_id'};

   local($plural) = "<TT>${term}</TT>s\\deferredindex $OP$id$CP$term$OP$id$CP";

   &gls_entry_init($label, $acronymtype, $name, $desc);

   &gls_set_sort($label, $sort);
   &gls_set_first($label, $text);
   &gls_set_firstplural($label, $plural);

   &gls_set_text($label, $text);
   &gls_set_plural($label, $plural);

   &gls_set_useriv($label, "<TT>$term</TT>");

   push @{$gls_entries{$acronymtype}}, $label;

   $_;
}

sub do_cmd_defappnourl{
   local($_) = @_;

   local($label, $term, $desc, $id, $pat);

   ($label,$pat) = &get_next_optional_argument;

   $term = &missing_braces unless
     s/$next_pair_pr_rx/$term=$2;''/eo;

   my $sort = $term;

   $label = $term unless $label;

   $desc = &missing_braces unless
     s/$next_pair_pr_rx/$desc=$2;''/eo;

   $id = ++$global{'max_id'};

   local($name) = "<TT>$term</TT><tex2html_gloindex_deferred>$OP$id$CP$term\@<TT>$term</TT>$OP$id$CP";

   $id = ++$global{'max_id'};

   local($text) = "<TT>$term</TT>\\deferredindex $OP$id$CP$term\@<TT>$term</TT>$OP$id$CP";

   $id = ++$global{'max_id'};

   local($plural) = "<TT>${term}</TT>s\\deferredindex $OP$id$CP$term$OP$id$CP";

   &gls_entry_init($label, $acronymtype, $name, $desc);

   &gls_set_sort($label, $sort);

   &gls_set_first($label, $text);
   &gls_set_firstplural($label, $plural);

   &gls_set_text($label, $text);
   &gls_set_plural($label, $plural);

   &gls_set_useriv($label, "<TT>$term</TT>");

   push @{$gls_entries{$acronymtype}}, $label;

   $_;
}

sub do_cmd_deflang{
   local($_) = @_;

   local($label, $term, $desc, $url, $id, $pat);

   ($label,$pat) = &get_next_optional_argument;

   $term = &missing_braces unless
     s/$next_pair_pr_rx/$term=$2;''/eo;

   $label = $term unless $label;

   $desc = &missing_braces unless
     s/$next_pair_pr_rx/$desc=$2;''/eo;

   $url = &missing_braces unless
     s/$next_pair_pr_rx/$url=$2;''/eo;

   $desc .= " URL: <A HREF=\"$url\">$url</A>";

   $id = ++$global{'max_id'};

   local($name) = "$term<tex2html_gloindex_deferred>$OP$id$CP$term$OP$id$CP";

   $id = ++$global{'max_id'};

   local($text) = "$term\\deferredindex $OP$id$CP$term$OP$id$CP";

   $id = ++$global{'max_id'};

   local($plural) = "${term}s\\deferredindex $OP$id$CP$term$OP$id$CP";

   &gls_entry_init($label, $acronymtype, $name, $desc);

   &gls_set_first($label, $text);
   &gls_set_firstplural($label, $plural);

   &gls_set_text($label, $text);
   &gls_set_plural($label, $plural);

   &gls_set_useriv($label, $term);

   push @{$gls_entries{$acronymtype}}, $label;

   $_;
}

sub do_cmd_lkernel{
   'LaTeX Kernel'. $_[0];
}

sub do_cmd_texprimitive{
   'TeX primitive'. $_[0];
}

sub do_cmd_pdftexprimitive{
   'PDFTeX primitive'. $_[0];
}

sub do_cmd_defgcs{
   local($_) = @_;

   local($extra,$label,$pat);
   local($id,$id2,$id3,$id4,$id5,$name,$syntax,$location,$summary,$argsummary);

   ($extra,$pat) = &get_next_optional_argument;
   ($label,$pat) = &get_next_optional_argument;

   $name = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$name=$2;''/eo;

   $label = $name unless ($label);

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id3=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id4=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id5=$1,$argsummary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE,
     "\\cmdname $OP$id$CP$name$OP$id$CP<tex2html_glocsindex_deferred>$OP$id2$CP$name$OP$id2$CP",
      $summary);

   &gls_set_sort($label, $name);

   &gls_set_first($label, "\\cmddef $OP$id3$CP$name$OP$id3$CP");

   &gls_set_text($label, "\\icmdname $OP$id4$CP$name$OP$id4$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "\\cmdname $OP$id5$CP$name$OP$id5$CP", $extra, '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgenv{
   local($_) = @_;


   local($id, $id2, $id3, $id4, $id5, $name,$syntax,$location,$summary,$argsummary);

   local($label,$pat) = &get_next_optional_argument;

   $name = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$name=$2;''/eo;

   $label = "env-$name" unless ($label);

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id3=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id4=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id5=$1,$argsummary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE,
     "<TT>".&unicode_entity('\\')
     . "begin" .&unicode_entity('{')
     . $name . &unicode_entity('}')
     . "</TT><tex2html_gloindex_deferred>$OP$id2$CP$name environment@<TT>$name</TT> environment$OP$id2$CP",
     $summary);

   &gls_set_sort($label, $name);

   &gls_set_first($label, "\\envdef $OP$id3$CP$name$OP$id3$CP");

   &gls_set_text($label, "\\ienvname $OP$id4$CP$name$OP$id4$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "\\envname $OP$id5$CP$name$OP$id5$CP", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defarara{
   local($_) = @_;


   local($id, $id2, $id3, $id4, $id5, $name,$syntax,$summary,$argsummary);

   local($label,$pat) = &get_next_optional_argument;

   $name = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$name=$2;''/eo;

   $label = "arara.$name" unless ($label);

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$syntax=$2;''/eo;

   local($location) = '<TT>arara</TT> directive';

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id4=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id5=$1,$argsummary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE,
     "<TT>$name</TT><tex2html_gloindex_deferred>$OP$id2${CP}arara directives@<TT>arara</TT> directives!$name@<CODE>$name</CODE>$OP$id2$CP",
     $summary);

   &gls_set_sort($label, $name);

   &gls_set_first($label, "<CODE>$name</CODE>");

   &gls_set_text($label, "<CODE>$name</CODE>");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<CODE>$name</CODE>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgidxactivechar{
   local($_) = @_;


   my($sort,$pat) = &get_next_optional_argument;

   my($id,$id2,$label,$char,$syntax,$location,$summary,$argsummary);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $sort = $char unless $sort;

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$argsummary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE, 
     "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP",
      $summary);

   &gls_set_sort($label, $sort);

   &gls_set_first($label, "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label, "<TT>$char</TT>\\indextt $OP$id2$CP$char$OP$id2$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgidxactivecharaccsupp{
   local($_) = @_;


   my($sort,$pat) = &get_next_optional_argument;

   my($id,$id2,$label,$char,$syntax,$location,$summary,$argsummary);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $sort = $char unless $sort;

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$argsummary=$2;''/eo;

   local($access);

   $access = &missing_braces unless
     s/$next_pair_pr_rx/$access=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE, 
     "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP",
      $summary);

   &gls_set_sort($label, $sort);

   &gls_set_first($label, "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label, "<TT>$char</TT>\\indextt $OP$id2$CP$char$OP$id2$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgchildidxactivechar{
   local($_) = @_;


   local($id,$id2,$label,$parent,$char,$summary);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $parent = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$parent=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$summary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE, 
     "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP", 
     $summary);

   local($sort) = join(' ', &gls_get_sort($parent),
                       (&gls_get_childcount($parent)+1));

   &gls_set_sort($label, $sort);

   &gls_set_first($label, "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label, "<TT>$char</TT>\\indextt $OP$id2$CP$char$OP$id2$CP");

   &gls_set_userkeys($label, '', '', '', "<TT>$char</TT>", '', '');

   &gls_set_parent($label, $parent);

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgidxactivecharcs{
   local($_) = @_;


   local($id,$id2,$label,$char,$syntax,$location,$summary,$argsummary);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   local($sort) = &unicode_entity('\\').$char;

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$argsummary=$2;''/eo;

   local $bksl = &unicode_entity('\\');

   &gls_entry_init($label, $SUMMARYTYPE,
    "<TT>$bksl$char</TT><tex2html_gloindex_deferred>$OP$id$CP$bksl$char$OP$id$CP",
    $summary);

   &gls_set_first($label, "<TT>$bksl$char</TT>\\indexttdef $OP$id$CP$bksl$char$OP$id$CP");

   &gls_set_text($label, "<TT>$bksl$char</TT>\\indextt $OP$id2$CP$bksl$char$OP$id2$CP");

   &gls_set_sort($label, $sort);

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$bksl$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgchar{
   local($_) = @_;

   local($id,$id2,$label,$char,$syntax,$location,$summary,$argsummary);

   local($sort,$pat) = &get_next_optional_argument;

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $sort = $char unless $sort;

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$argsummary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE, 
      "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP",
      $summary);

   &gls_set_sort($label, $sort);

   &gls_set_first($label, "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label, "<TT>$char</TT>\\indextt $OP$id2$CP$char$OP$id2$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgchildchar{
   local($_) = @_;


   local($id,$id2,$label,$parent,$char,$summary);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $parent = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$parent=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$summary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE,
     "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP",
     $summary);

   local($sort) = join(' ', &gls_get_sort($parent),
                       (&gls_get_childcount($parent)+1));

   &gls_set_sort($label, $sort);

   &gls_set_first($label, "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label, "<TT>$char</TT>\\indextt $OP$id2$CP$char$OP$id2$CP");

   &gls_set_parent($label, $parent);

   &gls_set_userkeys($label, '', '', '', "<TT>$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgxchildchar{
   local($_) = @_;


   local($id,$id2,$label,$parent,$char,$summary,$extra);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $parent = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$parent=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $extra = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$extra=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE,
      "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP",
      $summary);

   local($sort) = join(' ', &gls_get_sort($parent),
                       (&gls_get_childcount($parent)+1));

   &gls_set_sort($label, $sort);

   $id = ++$global{'max_id'};

   local($first) = "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP";

   if ($extra)
   {
      $id2 = ++$global{'max_id'};
      $first .= "\\index $OP$id2$CP$extra$OP$id2$CP";
   }

   &gls_set_first($label, $first);

   $id = ++$global{'max_id'};

   local($text) = "<TT>$char</TT>\\indextt $OP$id2$CP$char$OP$id2$CP";

   if ($extra)
   {
      $id2 = ++$global{'max_id'};
      $text .= "\\index $OP$id2$CP$extra$OP$id2$CP";
   }

   &gls_set_text($label, $text);

   &gls_set_userkeys($label, '', '', '', "<TT>$char</TT>", '', '');

   &gls_set_parent($label, $parent);

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgactivechar{
   local($_) = @_;


   local($id,$id2,$label,$char,$syntax,$location,$summary,$argsummary);

   local($sort,$pat) = &get_next_optional_argument;

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $sort = $char unless ($sort);

   $sort = &translate_commands($sort);

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$argsummary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE, 
     "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP",
      $summary);

   &gls_set_sort($label, $sort);

   &gls_set_first($label, "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label, "<TT>$char</TT>\\indextt $OP$id$CP$char$OP$id$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgchildactivechar{
   local($_) = @_;


   local($id,$id2,$id3,$id4,$label,$parent,$char,$summary);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $parent = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$parent=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id3=$1,$char=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id4=$1,$summary=$2;''/eo;

   &gls_entry_init($label, $SUMMARYTYPE,
      "<TT>$char</TT><tex2html_gloindex_deferred>$OP$id$CP$char$OP$id$CP",
      $summary);

   local($sort) = join(' ', &gls_get_sort($parent),
                       (&gls_get_childcount($parent)+1));

   &gls_set_sort($label, $sort);

   &gls_set_first($label,
     "<TT>$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label,
     "<TT>$char</TT>\\indextt $OP$id$CP$char$OP$id$CP");

   &gls_set_user($label, 4, "<TT>$char</TT>");

   &gls_set_parent($label, $parent);

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgactivecharcs{
   local($_) = @_;


   local($id,$label,$char,$syntax,$location,$summary,$argsummary);

   local($sort,$pat) = &get_next_optional_argument;

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $sort = $char unless ($sort);

   $sort = &translate_commands($sort);

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$argsummary=$2;''/eo;

   local $bksl = &unicode_entity('\\');

   &gls_entry_init($label, $SUMMARYTYPE,
     "<TT>$bksl$char</TT><tex2html_gloindex_deferred>$OP$id$CP$bksl$char$OP$id$CP",
      $summary);

   &gls_set_sort($label, "$bksl$sort");

   &gls_set_first($label, "<TT>$bksl$char</TT>\\indexttdef $OP$id$CP$bksl$char$OP$id$CP");

   &gls_set_text($label, "<TT>$bksl$char</TT>\\indextt $OP$id$CP$bksl$char$OP$id$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$bksl$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgsymcs{
   local($_) = @_;

   local($id,$char,$syntax,$location,$summary,$argsummary);

   local($label,$pat) = &get_next_optional_argument;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   local($label) = $char unless ($label);

   local $bksl = &unicode_entity('\\');

   local($sort) = "$bksl$char";

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$argsummary=$2;''/eo;

   $id = ++$global{'max_id'};

   &gls_entry_init($label, $SUMMARYTYPE,
     "<TT>$bksl$char</TT><tex2html_gloindex_deferred>$OP$id$CP$bksl$char$OP$id$CP",
      $summary);

   &gls_set_sort($label, $sort);

   $id = ++$global{'max_id'};

   &gls_set_first($label, "<TT>$bksl$char</TT>\\indexttdef $OP$id$CP$bksl$char$OP$id$CP");

   $id = ++$global{'max_id'};

   &gls_set_text($label, "<TT>$bksl$char</TT>\\indextt $OP$id$CP$bksl$char$OP$id$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$bksl$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgsymcsaccsupp{
   local($_) = @_;

   local($id,$char,$syntax,$location,$summary,$argsummary);

   local($label,$pat) = &get_next_optional_argument;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   local($label) = $char unless ($label);

   local $bksl = &unicode_entity('\\');
   local($sort) = "$bksl$char";

   $syntax = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$syntax=$2;''/eo;

   $location = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$location=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$summary=$2;''/eo;

   $argsummary = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$argsummary=$2;''/eo;

   local($access);

   $access = &missing_braces unless
     s/$next_pair_pr_rx/$access=$2;''/eo;

   $id = ++$global{'max_id'};

   &gls_entry_init($label, $SUMMARYTYPE,
     "<TT>$bksl$char</TT><tex2html_gloindex_deferred>$OP$id$CP$bksl$char$OP$id$CP",
      $summary);

   &gls_set_sort($label, $sort);

   $id = ++$global{'max_id'};

   &gls_set_first($label, "<TT>$bksl$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   $id = ++$global{'max_id'};

   &gls_set_text($label, "<TT>$bksl$char</TT>\\indextt $OP$id$CP$char$OP$id$CP");

   &gls_set_userkeys($label, $syntax, $location, $argsummary,
     "<TT>$bksl$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_defgchildsymcs{
   local($_) = @_;


   local($id,$id2,$label,$parent,$char,$summary);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   $parent = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$parent=$2;''/eo;

   $char = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$char=$2;''/eo;

   $summary = &missing_braces unless
     s/$next_pair_pr_rx/$id2=$1,$summary=$2;''/eo;

   local $bksl = &unicode_entity('\\');

   &gls_entry_init($label, $SUMMARYTYPE,
     "<TT>$bksl$char</TT><tex2html_gloindex_deferred>$OP$id$CP$bksl$char$OP$id$CP",
     $summary);

   local($sort) = join(' ', &gls_get_sort($parent),
                       (&gls_get_childcount($parent)+1));

   &gls_set_sort($label, $sort);

   &gls_set_first($label, "<TT>$bksl$char</TT>\\indexttdef $OP$id$CP$char$OP$id$CP");

   &gls_set_text($label, "<TT>$bksl$char</TT>\\indextt $OP$id2$CP$char$OP$id2$CP");

   &gls_set_parent($label, $parent);

   &gls_set_userkeys($label, '', '', '', "<TT>$bksl$char</TT>", '', '');

   push @{$gls_entries{$SUMMARYTYPE}}, $label;

   $_;
}

sub do_cmd_BeginArgList{
  local($_) = @_;

  "<UL>$_";
}

sub do_cmd_EndArgList{
  local($_) = @_;

  "</UL>$_";
}

sub do_cmd_csentryargitem{
  "<LI>" . &do_cmd_meta(@_);
}

sub do_cmd_csentryargitemstar{
  "<LI>" . @_[0];
}

sub do_cmd_nxidbtexfile{
   local($_) = @_;

   "<tex2html_idbtexfile_deferred>$_";
}

sub do_cmd_nxipagestyle{
   local($_) = @_;

   "<tex2html_ipagestyle_deferred>$_";
}

sub do_cmd_nxiappopt{
   local($_) = @_;

   "<tex2html_iappopt_deferred>$_";
}

sub do_cmd_nxiappoptstar{
   local($_) = @_;

   "<tex2html_iappoptstar_deferred>$_";
}

sub do_cmd_nxcmddef{
   local($_) = @_;

   "<tex2html_cmddef_deferred>$_";
}

sub do_cmd_nxgls{
   local($_) = @_;

   "<tex2html_gls_deferred>$_";
}

sub do_cmd_nxglspl{
   local($_) = @_;

   "<tex2html_glspl_deferred>$_";
}

sub do_cmd_nxGls{
   local($_) = @_;

   "<tex2html_Gls_deferred>$_";
}

sub do_cmd_nxglsi{
   local($_) = @_;

   "<tex2html_glsi_deferred>$_";
}

sub do_cmd_nxglsni{
   local($_) = @_;

   "<tex2html_glsni_deferred>$_";
}

sub do_cmd_nxglsplni{
   local($_) = @_;

   "<tex2html_glsplni_deferred>$_";
}

sub do_cmd_nxglslink{
   local($_) = @_;

   "<tex2html_glslink_deferred>$_";
}

sub do_cmd_nxGlsi{
   local($_) = @_;

   "<tex2html_Glsi_deferred>$_";
}

sub do_cmd_nxGlsni{
   local($_) = @_;

   "<tex2html_Glsni_deferred>$_";
}

sub do_cmd_nxisty{
   local($_) = @_;

   "<tex2html_isty_deferred>$_";
}

sub do_cmd_nxicls{
   local($_) = @_;

   "<tex2html_icls_deferred>$_";
}

sub do_cmd_nxitikzlibrary{
   local($_) = @_;

   "<tex2html_itikzlibrary_deferred>$_";
}

sub do_cmd_nxiappname{
   local($_) = @_;

   "<tex2html_iappname_deferred>$_";
}

sub do_cmd_nxicounter{
   local($_) = @_;

   "<tex2html_icounter_deferred>$_";
}

sub do_cmd_nxikeyvalopt{
   local($_) = @_;

   "<tex2html_ikeyvalopt_deferred>$_";
}

sub do_cmd_deferredidbtexfile{
  &do_cmd_idbtexfile(@_);
}

sub do_cmd_deferredipagestyle{
   &do_cmd_ipagestyle(@_);
}

sub do_cmd_deferrediappopt{
   &do_cmd_iappopt(@_);
}

sub do_cmd_deferrediappoptstar{
   &do_cmd_iappoptstar(@_);
}

sub do_cmd_deferredisty{
   &do_cmd_isty(@_);
}

sub do_cmd_deferredicls{
   &do_cmd_icls(@_);
}

sub do_cmd_deferrediappname{
   &do_cmd_iappname(@_);
}

sub do_cmd_deferredicounter{
   local($_) = @_;

   local($id, $name);

   $name = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$name=$2;''/eo;

   "<TT>$name</TT>$_";
}

sub do_cmd_deferredcmddef{
  &do_cmd_cmddef(@_);
}

sub do_cmd_deferredgls{
  &do_cmd_gls(@_);
}

sub do_cmd_deferredglspl{
  &do_cmd_glspl(@_);
}

sub do_cmd_deferredGls{
  &do_cmd_Gls(@_);
}

sub do_cmd_deferredglsi{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = &translate_commands(&gls_get_text($label));

   my $type = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text</A>$_";
}

sub do_cmd_glsi{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = &translate_commands(&gls_get_text($label));

   my $type = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text</A>$_";
}

sub do_cmd_deferredglsni{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = &translate_commands(&gls_get_user($label, 4));

   my $type = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text</A>$_";
}

sub do_cmd_glsni{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = &translate_commands(&gls_get_user($label, 4));

   my $type = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text</A>$_";
}

sub do_cmd_glsnistar{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   &gls_get_user($label, 4).$_;
}

sub do_cmd_deferredglsplni{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = &translate_commands(&gls_get_symbol($label));

   my $type = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text</A>$_";
}

sub do_cmd_glsplni{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = &translate_commands(&gls_get_symbol($label));

   my $type = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text</A>$_";
}

sub do_cmd_glsnl{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = &gls_get_user($label, 4);

   "$text$_";
}

sub do_cmd_deferredGlsi{
   local($_) = @_;

   local($id, $label);

   $label = &missing_braces unless
     s/$next_pair_pr_rx/$id=$1,$label=$2;''/eo;

   local($text) = ucfirst(&gls_get_text($label));

   my $type = &gls_get_type($label);

    my $anchors = '';

    while ($text=~s/(<A NAME="[^"]+">(?:<tex2html_anchor_[a-zA-Z_]+>)?<\/A>)//g)
    {
       $anchors .= $1;
    }

   "$anchors<A CLASS=\"gls\" HREF=\"$gls_file_mark{$type}#gls:$label\">$text</A>$_";
}

sub do_cmd_deferredglslink{
  &do_cmd_glslink(@_);
}

sub do_cmd_deferredikeyvalopt{
  &do_cmd_ikeyvalopt(@_);
}

sub do_cmd_deferredindex{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('', &named_index_entry($id, $text), $_);
}

sub do_cmd_gloindex{
   local($_) = @_;
   local($text,$id);

   $text = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$text=$2;''/eo;

   local($this_file) = $CURRENT_FILE;

   $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));

   $id = ++$global{'max_id'};

   join('',
      &named_index_entry($id, "$text|indexglo"),
      $_);
}

sub do_cmd_deferredgloindex{
  &do_cmd_gloindex(@_);
}

sub do_cmd_deferredglocsindex{
  &do_cmd_glocsindex(@_);
}

sub set_glossarystyle_acronyms{
  eval(<<'END_STYLE'); 
  sub do_cmd_glossaryheader{ 
    local($_) = @_;
    $_
  }

  sub do_cmd_glsgroupheading{ 
     local($_) = @_;

     local($id, $heading);

     $heading = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$heading=$2;''/eo;

    $_
  }

  sub do_cmd_glossaryentryfield{
     local($_) = @_;

     local($id, $id2, $id3, $id4, $id5, $label, $name, $desc, $symbol, $backlink);

     $label = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

     $name = &missing_braces unless
       s/$next_pair_pr_rx/$id2=$1;$name=$2;''/eo;

     $name=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

     $desc = &missing_braces unless
       s/$next_pair_pr_rx/$id3=$1;$desc=$2;''/eo;

     $desc=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

     $symbol = &missing_braces unless
       s/$next_pair_pr_rx/$id4=$1;$symbol=$2;''/eo;

     $backlink = &missing_braces unless
       s/$next_pair_pr_rx/$id5=$1;$backlink=$2;''/eo;

     "<DT>\\glstarget $OP$id$CP$label$OP$id$CP$OP$id2$CP<DFN>$name</DFN>$OP$id2$CP\n<DD>"
     . "$desc$_";
  }

  sub do_cmd_glossarysubentryfield{
     local($_) = @_;

     local($id, $id2, $id3, $id4, $id5, $id6, $level, 
       $label, $name, $desc, $symbol, $backlink);

     $level = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$level=$2;''/eo;

     $label = &missing_braces unless
       s/$next_pair_pr_rx/$id2=$1;$label=$2;''/eo;

     $name = &missing_braces unless
       s/$next_pair_pr_rx/$id3=$1;$name=$2;''/eo;

     $name=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

     $desc = &missing_braces unless
       s/$next_pair_pr_rx/$id4=$1;$desc=$2;''/eo;

     $desc=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

     $symbol = &missing_braces unless
       s/$next_pair_pr_rx/$id5=$1;$symbol=$2;''/eo;

     $backlink = &missing_braces unless
       s/$next_pair_pr_rx/$id6=$1;$backlink=$2;''/eo;
  
     "<P>\\glssubentryitem $OP$id$CP$label$OP$id$CP"
     ."\\glstarget $OP$id2$CP$label$OP$id2$CP$OP$id3$CP<DFN>$name</DFN>$OP$id3$CP"
     ."$desc\n$_";
  }

  sub do_env_theglossary{
    local($_) = @_;

     "<DL CLASS=\"acronymlist\">".&translate_commands("\\glossaryheader $_")."</DL>";
  }
END_STYLE
}

sub set_glossarystyle_summary{
  eval(<<'END_STYLE');
   sub do_cmd_glossaryheader{
      local($_)=@_;

      $sidepanelcontents = '';

      join('', 
           "<A NAME=\"top\"></A><P>", 
            &translate_commands("\\summarypreamble "),
            $_);
   }

   sub do_cmd_glsgroupheading{
     local($_) = @_;

     local($id, $heading);

     $heading = &missing_braces unless
      s/$next_pair_pr_rx/$id=$1,$heading=$2;''/eo;

     local($back) = '';

     unless ($headings=~/symbol/i)
     {
        $back = "<A HREF=\"#top\">Top</A>";
     }

     $heading=~s/gls(symbols|numbers)/ucfirst($1)/e;

     if ($sidepanelcontents=~/<A HREF="#$heading">/)
     {
        &write_warnings("Duplicate heading '$heading' found in summary\n");
        return $_;
     }

     $sidepanelcontents .= " |\n" if ($sidepanelcontents);

     $sidepanelcontents .= "<A HREF=\"#$heading\">$heading</A>";
   
     "<P>$back<DIV CLASS=\"summaryheading\"><A NAME=\"$heading\">$heading</A></DIV>".$_;
   }

   sub do_cmd_glossaryentryfield{
      local($_) = @_;

      local($id, $label, $name, $desc, $symbol, $backlink);

      $label = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

      $name = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$name=$2;''/eo;

      $name=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      $desc = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$desc=$2;''/eo;

      $desc=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      $symbol = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$symbol=$2;''/eo;

      $backlink = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$backlink=$2;''/eo;

      local($syntax) = &gls_get_user($label, 1);

      $syntax=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      $syntax = &translate_commands($syntax);

      local $bksl = &unicode_entity('\\');
      local $opbr = &unicode_entity('{');
      local $clbr = &unicode_entity('}');

      if ($name=~/<TT>${bksl}begin${opbr}([a-zA-Z]+\*?)${clbr}<\/TT>/)
      {
         $syntax .= '<TT>'
                 . &do_meta('body')
                 . "<B>${bksl}end${opbr}$1${clbr}</B></TT>";
      }

      local($location) = &gls_get_user($label, 2);

      $location=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      local($info) = "<DIV CLASS=\"summary-desc\">"
                    . ($location ? "<B>Defined in:</B> ".&translate_commands($location).".<P>" : '')
                    . &translate_commands($desc);

      local($argsummary) = &gls_get_user($label, 3);

      # strip comments from $argsummary

      $argsummary=~s/<tex2html_comment_mark>\d+[^\n]*\n//s;

      if ($argsummary)
      {
         $argsummary = "<H4>Argument Summary:</H4>$argsummary</DIV>";
      }
      else
      {
         $argsummary = "</DIV>\n";
      }

      $backlink=~s|<SPAN CLASS="level"><SPAN>[^<]+</SPAN></SPAN>||;

      if (&gls_get_referenced_childcount($label) > 0)
      {
         $argsummary = '';
         $backlink = "\\glsresetsubentrycounter ";
      }
      else
      {
         $argsummary=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

         $argsummary = &translate_commands($argsummary);

         $backlink = "&#x00A7;$backlink";
      }

      local($text) = "$syntax</DIV>\n<P>$info $backlink$argsummary";

      local($gloindex) = '';

      if ($name=~s/\\deferredgloindex\s*$OP(\d+)$CP(.*)$OP\1$CP//)
      {
         $gloindex = &do_cmd_gloindex("$OP$1$CP$2$OP$1$CP");
      }

      $name = &translate_commands($name);

      $global{'subentrycounter'} = 0;

      $id = ++$global{'max_id'};
      local($id2) = ++$global{'max_id'};

      "<DIV CLASS=\"summary-name\">\\glstarget $OP$id$CP$label$OP$id$CP$OP$id2$CP$name$OP$id2$CP$gloindex$text<P>$_";
   }

   sub do_cmd_glossarysubentryfield{
      local($_) = @_;

      local($id, $level, $label, $name, $desc, $symbol, $backlink);

      $level = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$level=$2;''/eo;

      $label = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$label=$2;''/eo;

      $name = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$name=$2;''/eo;

      $name=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      $desc = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$desc=$2;''/eo;

      $symbol = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$symbol=$2;''/eo;

      $backlink = &missing_braces unless
        s/$next_pair_pr_rx/$id=$1;$backlink=$2;''/eo;

      # child entries all dealt with by parent entry.

      local($count) = ++$global{'subentrycounter'};

      local($parent) = &gls_get_parent($label);

      unless (&gls_entry_defined($parent))
      {
         &write_warnings("do_cmd_glossarysubentryfield: parent `$parent' doesn't exist for child `$label'");
      }

      local($pre) = '';

      local($id2);

      local($argsummary) = &gls_get_user($parent, 3);

      local($sep);

      if ($count eq &gls_get_referenced_childcount($parent))
      {
         if ($argsummary)
         {
            $argsummary=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

            $argsummary = &translate_commands($argsummary);

            $argsummary = "<H4>Argument Summary:</H4>\n<P>$argsummary\n<P>";
         }

         $sep = ".\n</DIV>";
      }
      else
      {
         $argsummary = '';
         $sep = ";\n";
      }

      $desc=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      $desc = &translate_commands($desc);

      $id = ++$global{'max_id'};
      $id2 = ++$global{'max_id'};

      local($text) = "$desc &#x00A7;$backlink$sep$argsummary";

      "$pre\\glstarget $OP$id$CP$label$OP$id$CP$OP$id2$CP$count)$OP$id2$CP\n$text$_";
   }

  sub do_env_theglossary{
    local($_) = @_;

    $glsinlinesep = '';

     $TITLE = $gls_toctitle{$SUMMARYTYPE} unless $TITLE;

     &translate_commands("\\glossaryheader $_")."<P><A HREF=\"#top\">Top</A>";
  }

END_STYLE
}

sub do_cmd_idxcrossref{
   local($_) = @_;
   local($text,$loc);

   $text = &missing_braces unless
     s/$next_pair_pr_rx/$text=$2;''/eo;

   $loc = &missing_braces unless
     s/$next_pair_pr_rx/$loc=$2;''/eo;

   join(&do_real_idxcrossref($text), $_);
}

sub do_real_idxcrossref{
   local($text) = @_;

   local(@split) = split /\s*,\s*/, $text;
   local($level) = $#split+1;

   local($anchor) = $split[$#split];

   $anchor=~s/<[^>]*>//g;

   $anchor=~s/([^a-zA-Z0-9])/_/g;

   join('', "<EM>see</EM> <A HREF=\"#$level-$anchor\">",
     $text, "</A>");
}


sub do_cmd_ifscreenorother{
   local($_) = @_;

   local($screen, $other);

   $screen = &missing_braces unless
     s/$next_pair_pr_rx/$screen=$2;''/eo;

   $other = &missing_braces unless
     s/$next_pair_pr_rx/$other=$2;''/eo;

   $screen.$_;
}

sub do_cmd_mbox{$_[0]; }

sub make_singleauthor_title {
     local($alignc, $alignl , $t_author
         , $t_affil,$t_institute,$t_date,$t_address,$t_email,$t_authorURL) 
= (@_);
     my $t_title = '';
     my ($s_author_info, $e_author_info) = ('<DIV','</DIV>');
     $s_author_info .= ($USING_STYLES ? ' CLASS="author_info"' : '').'>';

     if ($t_author) {
         if ($t_authorURL) {
             local($href) = &translate_commands($t_authorURL);
             $href = &make_named_href('author'
                         , $href, "<STRONG>${t_author}</STRONG>");
             $t_title .= "\n<P$alignc>$href</P>";
         } else {
             $t_title .= "\n<P$alignc><STRONG>$t_author</STRONG></P>";
         }
     } else { &write_warnings("\nThere is no author for this document."); }

     if ($t_institute&&!($t_institute=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/)) {
         $t_title .= "\n<P$alignc><SMALL>$t_institute</SMALL></P>";}
     if ($t_affil&&!($t_affil=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/)) {
         $t_title .= "\n<P$alignc><I>$t_affil</I></P>";}
     if ($t_date&&!($t_date=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/)) {
         $t_title .= "\n<P$alignc><STRONG>$t_date</STRONG></P>";}
     if ($t_address&&!($t_address=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/)) {
#JOS:   $t_title .= "\n<P$alignl><SMALL>$t_address</SMALL></P>";
         $t_title .= "\n<P$alignc><SMALL>$t_address</SMALL></P>";
     }  # else { $t_title .= "\n<P$alignl>"}
     if ($t_email&&!($t_email=~/^\s*(($O|$OP)\d+($C|$CP))\s*\1\s*$/)) {
#JOS:   $t_title .= "\n<P$alignl><SMALL>$t_email</SMALL></P>";
         $t_title .= "\n<P$alignc><SMALL>$t_email</SMALL></P>";
     }  # else { $t_title .= "</P>" }
     join("\n", $s_author_info, $t_title, $e_author_info);
}




&ignore_commands( <<_IGNORED_CMDS_);
texorpdfstring # {}
ifpdf
else
fi
or
adminmedia
pdfinfo # {}
csuse # {}
phantomsection
usetikzlibrary # {}
glsnumberformat
setentrycounter # [] # {}
inputlabelformat
outputlabelformat
nopostdesc
spacefactor
obeyspaces
ifbookorother # {}
ifreportorother # {}
setdoublecolumnglo
null
breakenumi
indexmarker # {} # {}
continuenote
screencontinueline
reportcontinueline
bookcontinueline
continueline
widefigureenv
endwidefigureenv
imgresultfmt # {}
_IGNORED_CMDS_

local ($indexpreamble) = '';

sub do_cmd_indexpreamble{
   local($_) = @_;

   $indexpreamble = &missing_braces unless
     s/$next_pair_pr_rx/$indexpreamble=$2;''/eo;

   $_;
}

# This stuff is adapted from makeidx.perl:

sub add_book_idx {
    print "\nDoing the index ...";
    local($key, @keys, $next, $index, $old_key, $old_html);

    local($indexnav) = "";

    @keys = keys %printable_key;

    $currentindexlevel = 1;

    # include non- makeidx  index-entries

    foreach $key (keys %index)
    {
	next if $printable_key{$key};
	$old_key = $key;

	if ($key =~ s/###(.*)$//)
        {
	    next if $printable_key{$key};

	    push (@keys, $key);
	    $printable_key{$key} = $key;

	    if ($index{$old_key} =~ /HREF="([^"]*)"/i)
            {
		$old_html = $1;
		$old_html =~ /$dd?([^#\Q$dd\E]*)#/;
		$old_html = $1;
	    }
            else
            { 
               $old_html = ''
            }
	    $index{$key} = $index{$old_key} . $old_html."</A>\n |\n";
	};
    }

    @keys = sort book_makeidx_keysort @keys;
    @keys = grep(!/\001/, @keys);

    local($previous) = '';

    foreach $key (@keys)
    {
       local($initial) = uc(substr($key, 0, 1));

       $initial = '!' unless ($initial=~/[A-Z]/);

       unless ($initial eq $previous)
       {
          local ($tag) = $initial eq '!' ? "Symbols" : $initial;

          unless ($initial eq '!' or not $previous)
          {
             $index .= "<P><DIV CLASS=\"indextotop\"><A HREF=\"#top\">Top</A></DIV><P>";
          }

          $index .= join('', "<P><DIV CLASS=\"indexheading\"><B><A NAME=\"idx:$tag\">", 
            $tag, "</A></B></DIV><P>");

          $indexnav .= "\n| " if ($indexnav);

          $indexnav .= "<A HREF=\"#idx:$tag\"><B>$tag</B></A>";
       }

       $index .= &add_book_idx_key($key);

       $previous = $initial;
    }
    $index = '<DIV CLASS="indexentry">'.$index unless ($index =~ /^\s*<DIV>/);

    $sidepanelcontents = $indexnav;

    s/$idx_mark/<A NAME="top"><\/A>$indexpreamble<DIV CLASS=\"index\">\n$index\n<\/DIV><P><DIV CLASS=\"indextotop\"><A HREF="#top">Top<\/A><\/DIV>/o;
}

sub book_makeidx_keysort {
  local($x, $y) = ($a,$b);

  local $result = 0;

  while ($result == 0)
  {
     if ($x eq '' and $y eq '')
     {
        last;
     }

     if ($x eq '')
     {
        $result = -1;
        last;
     }

     if ($y eq '')
     {
        $result = 1;
        last;
     }


     $x=~s/^(&#x[\da-fA-F]+;|&#\d+;|[a-zA-Z]|.)//;

     my $thisX = $1;

     $y=~s/^(&#x[\da-fA-F]+;|&#\d+;|[a-zA-Z]|.)//;

     my $thisY = $1;

     my $xisletter = 0;
     my $yisletter = 0;

     if ($thisX=~/&#x([\da-fA-F]+);/)
     {
        $thisX = hex($1);
     }
     elsif ($thisX=~/&#(\d+);/)
     {
        $thisX = $1;
     }
     elsif ($thisX=~/^[a-zA-Z]$/)
     {
        $thisX = lc($thisX);
        $xisletter = 1;
     }
     else
     {
        $thisX = ord($thisX);
     }

     if ($thisY=~/&#x([\da-fA-F]+);/)
     {
        $thisY = hex($1);
     }
     elsif ($thisY=~/&#(\d+);/)
     {
        $thisY = $1;
     }
     elsif ($thisY=~/^[a-zA-Z]$/)
     {
        $thisY = lc($thisY);
        $yisletter = 1;
     }
     else
     {
        $thisY = ord($thisY);
     }

     if ($xisletter and $yisletter)
     {
        $result = ($thisX cmp $thisY);
     }
     elsif ($xisletter)
     {
        $result = 1;
     }
     elsif ($yisletter)
     {
        $result = -1;
     }
     else
     {
        $result = ($thisX <=> $thisY);
     }
  }

  $result
}

 
sub add_book_idx_key {
    local($key) = @_;
    local($index, $next);

    if (($index{$key} eq '@' )&&(!($index_printed{$key})))
    { 
	$index .= "\n<DIV CLASS=\"indexloc\">".&book_print_key."</DIV>\n<BR>"; 
    }
    elsif (($index{$key})&&(!($index_printed{$key})))
    {
	$next = "<DIV CLASS=\"indexentry\">".&book_print_key."</DIV>\n<DIV CLASS=\"indexloc\">"
          . &print_book_idx_links;

	$index .= $next."</DIV>\n<BR>";
	$index_printed{$key} = 1;
    }

    if ($sub_index{$key})
    {
	local($subkey, @subkeys, $subnext, $subindex);
	@subkeys = sort(split("\004", $sub_index{$key}));

	$index .= "<DIV CLASS=\"indexentry\">".&book_print_key."</DIV>\n" 
           unless $index_printed{$key};
	$index .= "<DIV CLASS=\"index\">\n"; 

        $currentindexlevel++;

	foreach $subkey (@subkeys)
        {
	    $index .= &add_book_sub_idx_key($subkey) unless ($index_printed{$subkey});
	}

        $currentindexlevel--;

	$index .= "</DIV>\n";
    }
    return $index;
}

local($currentindexlevel) = 0;

sub book_print_key {
    local($text) = $printable_key{$key};

    local($anchor) = $text;

    $anchor=~s/<[^>]*>//g;

    $anchor=~s/([^a-zA-Z0-9])/_/g;

    "$sidx_style<A NAME=\"$currentindexlevel-$anchor\">$text</A>$eidx_style"
}

sub print_book_idx_links {
    local($links) = $index{$key};

    local(@array) = split /\s+\|\s+/, $links;

    foreach $elem (@array)
    {
       if ($elem=~/idxcrossref(.*)$/)
       {
          local($text) = $1;
          $elem = &do_real_idxcrossref($text);
       }
    }

    $links = join(" |\n", @array);

    $links =~ s/(\n )?\| $//;

    $links 
}

sub add_book_sub_idx_key {
   local($key) = @_;
   local($index, $next);

   if ($sub_index{$key})
   {
      local($subkey, @subkeys, $subnext, $subindex);
      @subkeys = sort(split("\004", $sub_index{$key}));

      if ($index{$key})
      {
         $next = "<DIV CLASS=\"indexentry\">".&book_print_key."</DIV>\n<DIV CLASS=\"indexloc\">". &print_book_idx_links;
         $index .= $next."\n";
      }
      else
      {
         $index .= "<DIV CLASS=\"indexentry\">".&book_print_key  unless $index_printed{$key}
      }

      $index .= "</DIV>\n<DIV CLASS=\"index\">\n";

      $currentindexlevel++;

      foreach $subkey (@subkeys)
      {
         $index .= &add_book_sub_idx_key($subkey) unless ($index_printed{$subkey})
      }

      $index .= "</DIV>\n";

      $currentindexlevel--;
   }
   elsif ($index{$key})
   {
      $next = "<DIV CLASS=\"indexentry\">".&book_print_key."</DIV>\n<DIV CLASS=\"indexloc\">". &print_book_idx_links;
      $index .= $next."</DIV>\n<BR>";
   }

   $index_printed{$key} = 1;
   return $index;
}

sub book_named_index_entry {
    local($br_id, $str) = @_;

    # escape the quoting etc characters
    # ! -> \001
    # @ -> \002
    # | -> \003
    $* = 1; $str =~ s/\n\s*/ /g; $* = 0; # remove any newlines
    # protect \001 occurring with images
    $str =~ s/\001/\016/g;

    $str =~ s/\\\\/\011/g;
    $str =~ s/\\;SPMquot;/\012/g;
    $str =~ s/;SPMquot;!/\013/g;
    $str =~ s/!/\001/g;
    $str =~ s/\013/!/g;
    $str =~ s/;SPMquot;@/\015/g;
    $str =~ s/@/\002/g;
    $str =~ s/\015/@/g;
    $str =~ s/;SPMquot;\|/\017/g;
    $str =~ s/\|/\003/g;
    $str =~ s/\017/|/g;
    $str =~ s/;SPMquot;(.)/\1/g;
    $str =~ s/\012/;SPMquot;/g;
    $str =~ s/\011/\\\\/g;

    local($key_part, $pageref) = split("\003", $str, 2);
    local(@keys) = split("\001", $key_part);

    $TITLE = $saved_title if (($saved_title)&&(!($TITLE)||($TITLE eq $default_title)));
    $TITLE = $before unless $TITLE;

    local($words) = '';
    if ($SHOW_SECTION_NUMBERS) { $words = &make_idxnum; }
    elsif ($SHORT_INDEX) { $words = &make_shortidxname; }
    else { $words = &make_idxname; }
    local($super_key) = '';
    local($sort_key, $printable_key, $cur_key);

    foreach $key (@keys)
    {
	$key =~ s/\016/\001/g; # revert protected \001s

	($sort_key, $printable_key) = split("\002", $key);

	if ($printable_key =~ /tex2html_anchor_mark/ )
        {
	    $printable_key =~ s/><tex2html_anchor_mark><\/A><A//g;
	    local($tmpA,$tmpB) = split("NAME=\"", $printable_key);
	    ($tmpA,$tmpB) = split("\"", $tmpB);
	    $ref_files{$tmpA}='';
	    $index_labels{$tmpA} = 1;
	}

	if ($printable_key =~ /$cross_ref_mark/ )
        {
	    local($label,$id,$ref_label);
	    $printable_key =~ s/$cross_ref_mark#([^#]+)#([^>]+)>$cross_ref_mark/
	        do { ($label,$id) = ($1,$2);
		    $ref_label = $external_labels{$label} unless
			($ref_label = $ref_files{$label});
		    '"' . "$ref_label#$label" . '">' .
		    &get_ref_mark($label,$id)}/geo;
	}

	$printable_key =~ s/<\#[^\#>]*\#>//go;

	$printable_key =~ s/\&\#;\'134/\\/g;
	$printable_key =~ s/\&\#;\`<BR> /\\/g;
	$printable_key =~ s/\&\#;*SPMquot;92/\\/g;

	$sort_key .= "@$printable_key" if !($sort_key);

	if ($super_key)
        {
	    $cur_key = $super_key . "\001" . $sort_key;
	    $sub_index{$super_key} .= $cur_key . "\004";
	}
        else
        {
	    $cur_key = $sort_key;
	}

	$index{$cur_key} .= ""; 

	if (!($printable_key) && ($printable_key{$cur_key}))
	{
           $printable_key = $printable_key{$cur_key};
        } 

	if (!($printable_key{$cur_key} =~ /tex2html_anchor_mark/ ))
	{
           $printable_key{$cur_key} = $printable_key || $key;
        }

	$super_key = $cur_key;
    }

    if ($pageref) {
	if ($pageref eq "\(" ) { 
	    $pageref = ''; 
	    $next .= " from ";
	} elsif ($pageref eq "\)" ) { 
	    $pageref = ''; 
	    local($next) = $index{$cur_key};
	    $next =~ s/(\n )?\| $//;
	    $index{$cur_key} = "$next to ";
	}
    }

    if ($pageref) {
	$pageref =~ s/\s*$//g;	# remove trailing spaces
	if (!$pageref) { $pageref = ' ' }
	$pageref =~ s/see/<EM>see <\/EM> /g;

	local($tmp) = "do_cmd_$pageref";
	if (defined &$tmp) {
	    $words = &$tmp("<#0#>$words<#0#>");
	    $words =~ s/<\#[^\#]*\#>//go;
	    $pageref = '';
	}
    }
    if ($pageref) {
	if ($pageref =~ /tex2html_anchor_mark/ ) {
	    $pageref =~ s/><tex2html_anchor_mark><\/A><A//g;
	    local($tmpA,$tmpB) = split("NAME=\"", $pageref);
	    ($tmpA,$tmpB) = split("\"", $tmpB);
	    $ref_files{$tmpA}='';
	    $index_labels{$tmpA} = 1;
	}

	if ($pageref =~ /$cross_ref_mark/ ) {
	    local($label,$id,$ref_label);
	    $pageref =~ s/$cross_ref_mark#([^#]+)#([^>]+)>$cross_ref_mark/
	      do { ($label,$id) = ($1,$2);
		$ref_files{$label} = ''; # ???? RRM
		if ($index_labels{$label}) { $ref_label = ''; } 
		else { $ref_label = $external_labels{$label} 
		    unless ($ref_label = $ref_files{$label});
		}
		'"' . "$ref_label#$label" . '">' .
		  &get_ref_mark($label,$id)}/geo;
	}
	$pageref =~ s/<\#[^\#>]*\#>//go;

	if ($pageref eq ' ') { $index{$cur_key}='@'; }
	else { $index{$cur_key} .= $pageref . "\n | "; }
    } else {
	local($thisref) = &make_named_href('',"$CURRENT_FILE#$br_id",$words);
	$thisref =~ s/\n//g;
	$index{$cur_key} .= $thisref."\n | ";
    }
 
    "<A NAME=\"$br_id\">$anchor_invisible_mark<\/A>";
}

# modify cite to use <CITE> tag
sub process_real_cite {
    local($mode,$text) = @_;
    my $has_text = (($text)? 1 : 0);
#    local($target) = 'contents';print "\nCITE:$text";
    # process the text from \htmlcite or \hypercite
    if ($has_text) {
	$text = &balance_inner_tags($text) 
	    if $use_label =~ (/<\/([A-Z]+)>($math_verbatim_rx.*)<\1>/);
	$text = &translate_environments($text);
	$text = &simplify(&translate_commands($text))
	    if ($use_label =~ /\\/ );
    }

    my $label, $cite_key, $pretag, @cite_keys;
    local($optional_text,$dummy) =  &get_next_optional_argument;
    if ($mode =~ /external/) {
#	$target = '';
	$pretag = $optional_text; $optional_text = '';
	$pretag = &translate_commands($pretag) if ($pretag =~ /\\/);
    } else {
	$optional_text = ", $optional_text" if $optional_text;
    }
    s/^\s*\\space//o;		# Hack - \space is inserted in .aux
    s/$next_pair_pr_rx//o||s/$next_pair_rx//o;
    if (!($cite_key = $2)) {
	print "\n *** Cannot find citation argument\n";
	return ($_);
    }
    @cite_keys = (split(/,/,$cite_key));
    my ($citations, $join) = ('',',');
    $join  = '' if ($text);
    foreach $cite_key (@cite_keys) {
	$cite_key =~ s/(^\s+|\s+$)//g;
	$cite_key =~ s/(^\s+|\s+$)//g;
    # RRM:  if the URL and printable-key are known already, then use them...
	$cite_key =~ s/$label_rx/_/g;
	$label = $cite_key;
	if ($mode eq "nocite") {
	    # nothing more to do, no citations
	} elsif ( ($SEGMENT) && ($cite_info{$cite_key})
		&& ($ref_files{"cite_$cite_key"}) ) {
	    $join  = "," unless ($text);
	    $text = $cite_info{$cite_key} unless ($text);
	    $citations .= join('', $join
		, &make_named_href($label,$ref_files{'cite_'."$cite_key"},$text));
	} elsif (($mode eq "external")&&($external_labels{$pretag."cite_$cite_key"})) {
	    $join  = "," unless ($text);
	    $text = $cross_ref_visible_mark unless ($text);
	    $citations .= join('', $join
		, &make_named_href($label
		    , $external_labels{$pretag.'cite_'."$cite_key"}."\#$label"
		    , $text)
		);
	} elsif ($mode eq 'external') {
	    $join  = "," unless ($text);
	    &write_warnings("\nExternal reference missing for citation: $pretag$cite_key");
	    $citations .= "$text$join#!$pretag$cite_key!#";
        } else {
	    $join  = "," unless ($text);
	    #Replace the key...
	    $citations .= "$join#$cite_key#$cite_mark#$bbl_nr#$text#$cite_mark#";
        }
	$text = '';
    }

    $citations =~ s/^\s*,\s*//;

    if ($has_text)
    {
      join('', '<CITE>', $citations,  $optional_text, '</CITE>', $_)
    }
    else
    {
      join('', '<CITE>[', $citations,  $optional_text, ']</CITE>', $_)
    }
}

sub replace_image_marks {
    # Modifies $_

    s/$image_mark#([^#]+)#([\.,;:\)\]])?(\001)?([ \t]*\n?)(\001)?/
        &map_image_object($1)."$2$4"/ego;
}

sub map_image_object{
   local($id) = @_;

   local($img) = $id_map{$id};

   local($alt) = '';

   if ($img=~s/ALT="([^"]*)"//)
   {
      $alt = $1;
   }

   $img=~s/SRC="([^"]+)"/DATA="$1"/;

   local($imgfile) = $1;

   local($type)=$IMAGE_TYPE;

   if ($imgfile=~/\.([a-zA-Z])$/)
   {
      $type = lc($1);
   }

   $img=~s/<IMG\b/<OBJECT TYPE="image\/$type"/;

   if ($alt=~/.html?$/)
   {
      local($file) = "imagedesc/$alt";

      if (-e $file)
      {
         if (open FD, $file)
         {
            $alt = '';

            while (<FD>)
            {
               $alt .= $_;
            }

            $alt .= ' End of Image.<P>';
            close FD;
         }
         else
         {
            &write_warnings("Can't open '$file' $!");
         }
      }
      else
      {
        &write_warnings("Image description file '$file' doesn't exist");
      }
   }
   else
   {
     $alt=~s/\\commasym\s*/,/g;
     $alt=~s/\\space\s*/ /g;
   }

   "$img$alt</OBJECT>";
}


1;	# Must be last line
